      PROGRAM ANEOSTEST
C
C      PROGRAM TO INITIALIZE ANEOS AND CALL IT ONCE
C
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C     DEFINE NUMBER OF POINTS AT WHICH DENSITY, TEMPERATURE ARE EVALUATED
C
      PARAMETER (NDENS=51)
      PARAMETER (NTEMP=51)
C
      DIMENSION IZETL(21)
      COMMON /FILEOS/ KLST, KINP
      COMMON /ANGELX/ W,Y,ALFA,BETA,DADT,DADR,DBDT,ZZ,ET,
     &           SN,CVN,EN,PN,PM,EM,SM,CVM,EC,PC,RHO0,RHO00,ZVIB
      COMMON /ANEEL/ TEVX,RHOX,ABARX,ZBARM,T32X,FNX
     &  ,PE,EE,SE,CVE,DPTE,DPRE
     &  ,NMATSX,IIZX
      COMMON /ANEDIS/ GAMMA,PSI,THETA
      DIMENSION RHO(NDENS),TEMP(NTEMP)
      DIMENSION EA(NDENS,NTEMP),SA(NDENS,NTEMP),
     &          GA(NDENS,NTEMP),PSIA(NDENS,NTEMP)
      DIMENSION PA(NDENS,NTEMP),PCA(NDENS,NTEMP),PNA(NDENS,NTEMP),
     &          PMA(NDENS,NTEMP),PEA(NDENS,NTEMP)
      DIMENSION WA(NDENS,NTEMP),YA(NDENS,NTEMP),ALFAA(NDENS,NTEMP),
     & ZZA(NDENS,NTEMP),THETAA(NDENS,NTEMP),GAMMAA(NDENS,NTEMP)
	
C
C    SET RANGES FOR OUTPUT PLOTS IN DENSITY AND TEMPERATURE
C
      DATA RMIN,RMAX,TMIN,TMAX/1.0D-5,1.D1,1.D3,1.D5/
C
      OPEN(10,FILE='ANEOS.INPUT',STATUS='OLD')
      OPEN(12,FILE='ANEOS.OUTPUT')
      OPEN(15,FILE='ANEOS.ARRAYS')
      OPEN(16,FILE='ANEOS.PRESS')
C      OPEN(17,FILE='ANEOS.ENERGY')
      OPEN(18,FILE='ANEOS.ENTROPY')
      OPEN(19,FILE='ANEOS.GIBBS')
C      OPEN(20,FILE='ANEOS.PSI')
      OPEN(21,FILE='ANEOS.PC')
      OPEN(22,FILE='ANEOS.PN')
      OPEN(23,FILE='ANEOS.PM')
      OPEN(24,FILE='ANEOS.PE')
C      OPEN(16,FILE='ANEOS.W')
C      OPEN(17,FILE='ANEOS.Y')
C      OPEN(18,FILE='ANEOS.ALFA')
C      OPEN(19,FILE='ANEOS.ZZ')
C      OPEN(20,FILE='ANEOS.GAMMA')
C      OPEN(21,FILE='ANEOS.THETA')
C
      TCONV=1.16054D4
C
C     DEFINE RANGES OF DENSITY, TEMPERATURE
C
      DO 10 I=1,NDENS    !density is computed in equal log intervals
      FRACPWR=DFLOAT(I-1)/DFLOAT(NDENS-1)
      RHO(I)=RMAX*(RMIN/RMAX)**FRACPWR
  10  CONTINUE
C
C      DELT=(TMAX-TMIN)/DFLOAT(NTEMP-1)
      DO 20 J=1,NTEMP    !temperature is in equal log intervals
      FRACTWR=DFLOAT(J-1)/DFLOAT(NTEMP-1)
C      TEMP(J)=TMIN+DELT*DFLOAT(J-1)
      TEMP(J)=TMIN*(TMAX/TMIN)**FRACTWR
  20  CONTINUE
C
C     INITIALIZE ANALYTIC EOS
C
      KLST=12
      KINP=10
      M=0
      IZETL(1)=-1
      CALL ANEOS2 (1,1,0,IZETL)
C
C    make repeated calls to ANEOS1 to construct the property arrays
C
      DO 100 I=1,NDENS
      DO 200 J=1,NTEMP
C
C     CALL ANEOS FOR DIRECT CALCULATIONS
C
C      CALL ANEOS1 (TEMP(J)/TCONV,RHO(I),P,E,S,CV,DPDT,DPDR,M)
      CALL ANEOSD(TEMP(J)/TCONV,RHO(I),P,E,S,CV,DPDT,DPDR,FKROS,CS,
     &  KPA,1)
C
      PA(I,J)=P*1.D-10
      EA(I,J)=E*1.D-4
      SA(I,J)=S*1.D-4/TCONV
      GA(I,J)=EA(I,J)+(P/RHO(I))*1.D-4-TEMP(J)*SA(I,J)
      PSIA(I,J)=DLOG10(PSI)
      PCA(I,J)=PC*1.D-10
      PNA(I,J)=PN*1.D-10
      PMA(I,J)=PM*1.D-10
      PEA(I,J)=PE*1.D-10
      WA(I,J)=W
      YA(I,J)=Y
      ALFAA(I,J)=ALFA
      ZZA(I,J)=ZZ
      GAMMAA(I,J)=GAMMA
      THETAA(I,J)=THETA
C
C    COMPUTE MOLECULAR PRESSURE TERM DIRECTLY:
C
C      PMA(I,J)=-RHO(I)*TEMP(J)*(PSI*ALFA)/(1.D0+PSI)
C
 200  CONTINUE
 100  CONTINUE
C
C     WRITE OUT THE ARRAYS IN A MATHEMATICA-FRIENDLY FORMAT
C
      WRITE(15,1000) 'PRESSURE, GPA'
      WRITE(15,2000)  (RHO(I),I=1,NDENS)
      DO J=1,NTEMP
      WRITE(15,3000) TEMP(J),(PA(I,J),I=1,NDENS)
      WRITE(16,4000)         (PA(I,J),I=1,NDENS)
      ENDDO
C
C      WRITE(15,1000) 'ENERGY, J/KG'
C      WRITE(15,2000)  (RHO(I),I=1,NDENS)
C      DO J=1,NTEMP
C      WRITE(15,3000) TEMP(J),(EA(I,J),I=1,NDENS)
C      WRITE(17,4000)         (EA(I,J),I=1,NDENS)
C      ENDDO
C
      WRITE(15,1000) 'ENTROPY, J/KG-K'
      WRITE(15,2000)  (RHO(I),I=1,NDENS)
      DO J=1,NTEMP
      WRITE(15,3000) TEMP(J),(SA(I,J),I=1,NDENS)
      WRITE(18,4000)         (SA(I,J),I=1,NDENS)
      ENDDO
C
      WRITE(15,1000) 'GIBBS ENERGY, J/KG'
      WRITE(15,2000)  (RHO(I),I=1,NDENS)
      DO J=1,NTEMP
      WRITE(15,3000) TEMP(J),(GA(I,J),I=1,NDENS)
      WRITE(19,4000)         (GA(I,J),I=1,NDENS)
      ENDDO
C
C      WRITE(15,1000) 'LOG10(PSI)'
C      WRITE(15,2000)  (RHO(I),I=1,NDENS)
C      DO J=1,NTEMP
C      WRITE(15,3000) TEMP(J),(PSIA(I,J),I=1,NDENS)
C      WRITE(20,4000)         (PSIA(I,J),I=1,NDENS)
C      ENDDO
C
      WRITE(15,1000) 'COLD PRESSURE, GPA'
      WRITE(15,2000)  (RHO(I),I=1,NDENS)
      DO J=1,NTEMP
      WRITE(15,3000) TEMP(J),(PCA(I,J),I=1,NDENS)
      WRITE(21,4000)         (PCA(I,J),I=1,NDENS)
      ENDDO
C
      WRITE(15,1000) 'NUCLEAR PRESSURE, GPA'
      WRITE(15,2000)  (RHO(I),I=1,NDENS)
      DO J=1,NTEMP
      WRITE(15,3000) TEMP(J),(PNA(I,J),I=1,NDENS)
      WRITE(22,4000)         (PNA(I,J),I=1,NDENS)
      ENDDO
C
      WRITE(15,1000) 'MOLECULAR PRESSURE, GPA'
      WRITE(15,2000)  (RHO(I),I=1,NDENS)
      DO J=1,NTEMP
      WRITE(15,3000) TEMP(J),(PMA(I,J),I=1,NDENS)
      WRITE(23,4000)         (PMA(I,J),I=1,NDENS)
      ENDDO
C
      WRITE(15,1000) 'ELECTRON PRESSURE, GPA'
      WRITE(15,2000)  (RHO(I),I=1,NDENS)
      DO J=1,NTEMP
      WRITE(15,3000) TEMP(J),(PEA(I,J),I=1,NDENS)
      WRITE(24,4000)         (PEA(I,J),I=1,NDENS)
      ENDDO
C
C      WRITE(15,1000) 'W FUNCTION'
C      WRITE(15,2000)  (RHO(I),I=1,NDENS)
C      DO J=1,NTEMP
C      WRITE(15,3000) TEMP(J),(WA(I,J),I=1,NDENS)
C      WRITE(16,4000)         (WA(I,J),I=1,NDENS)
C      ENDDO
C
C      WRITE(15,1000) 'Y FUNCTION'
C      WRITE(15,2000)  (RHO(I),I=1,NDENS)
C      DO J=1,NTEMP
C      WRITE(15,3000) TEMP(J),(YA(I,J),I=1,NDENS)
C      WRITE(17,4000)         (YA(I,J),I=1,NDENS)
C      ENDDO
C
C      WRITE(15,1000) 'ALFA FUNCTION'
C      WRITE(15,2000)  (RHO(I),I=1,NDENS)
C      DO J=1,NTEMP
C      WRITE(15,3000) TEMP(J),(ALFAA(I,J),I=1,NDENS)
C      WRITE(18,4000)         (ALFAA(I,J),I=1,NDENS)
C      ENDDO
C
C      WRITE(15,1000) 'ZZ FUNCTION'
C      WRITE(15,2000)  (RHO(I),I=1,NDENS)
C      DO J=1,NTEMP
C      WRITE(15,3000) TEMP(J),(ZZA(I,J),I=1,NDENS)
C      WRITE(19,4000)         (ZZA(I,J),I=1,NDENS)
C      ENDDO
C
C      WRITE(15,1000) 'GAMMA FUNCTION'
C      WRITE(15,2000)  (RHO(I),I=1,NDENS)
C      DO J=1,NTEMP
C      WRITE(15,3000) TEMP(J),(GAMMAA(I,J),I=1,NDENS)
C      WRITE(20,4000)         (GAMMAA(I,J),I=1,NDENS)
C      ENDDO
C
C      WRITE(15,1000) 'THETA FUNCTION'
C      WRITE(15,2000)  (RHO(I),I=1,NDENS)
C      DO J=1,NTEMP
C      WRITE(15,3000) TEMP(J),(THETAA(I,J),I=1,NDENS)
C      WRITE(21,4000)         (THETAA(I,J),I=1,NDENS)
C      ENDDO
C
      STOP
1000  FORMAT(//3X,A30//)
2000  FORMAT(15X,51(1PE15.6)/)
3000  FORMAT(52(1PE15.6))
4000  FORMAT(51(1PE15.6))
C
      END
