C
C
      SUBROUTINE ANTOMF
C
C***********************************************************************
C
C     This routine computes the temperature dependent parts
C     of THOMAS-FERMI eos. Single or average element version.
C     Original method and routines by D. J. McCloskey
C     Modified for aneos by S. L. Thompson  10/88
C     All inputs and outputs are in cgsev units
C
C     Inputs and outputs are in /ANEEL/ and /ANE2/
C
C     Inputs:
C
C     TEVX = temperature in ev
C     RHOX = density
C     ABARX = average atomic number
C     ZBARM = average atomic weight
C
C     Outputs:
C
C     PE  = pressure
C     EE  = energy
C     SE  = entropy
C     CVE = dE/dT = heat capacity
C     DPTE = dP/dT
C     DPRE = dP/dRHO
C     ZBAR = ionization number
C
C     The thermodynamic functions are determined from an interpolation
C     in a scaled free energy table. The scaled function is of form
C
C       FreeE(rho,t) - FreeE(rho,0) = - C4 * Tf * F(x,y)
C
C       Tk = 11605.333 * Tev = ev * Tev
C       Tf = C2 * Tk
C       x = log( C1 / rho )
C       y = log( 1 + Cf * w )
C       w = C2 * Tk * ( C1 / rho )**(2/3)
C
C       The constants are functions of zbar, abar and various
C       physical constants.
C
C****************************************** last mod  slt 4/89 *********
C
C    READ IN FILE WITH DATA IN THE SC DATA STATEMENT
C
C      OPEN(27,FILE='ANTOMF.DAT')
C      DO J=1,528
C        READ(27,1000) (TC(I,J),I=1,13)
C      END DO
C 1000 FORMAT(13(1PD15.8))
C      STOP
C
C
C
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C                    inputs
      COMMON /ANEEL/ TEVX,RHOX,ABARX,ZBARM,T32X,FNX
C        outputs
     &  ,PE,EE,SE,CVE,DPTE,DPRE
C        inputs
     &  ,NMATSX,IIZX
      DIMENSION THOUTX(6)
      EQUIVALENCE (THOUTX,PE)
      COMMON /ANE2/ CRHS2P,CRLS2P,ZBAR,FKROS
      SAVE  /ANE2/,/ANEEL/,SC,TC
      PARAMETER (AVOGAD=6.0232D23)
      PARAMETER (ELMASS=9.1084D-28)
C     PARAMETER (ELCHAR=4.80288D-10)
      PARAMETER (PIKON=3.141592653589793D0)
      PARAMETER (BOLTS=1.38046D-16)
      PARAMETER (PLANCK=6.6252D-27)
      PARAMETER (ELKON8=1.60207D-12)
      PARAMETER (EV=ELKON8/BOLTS)
      PARAMETER (ANV13=1.D0/3.D0)
      PARAMETER (ANV23=2.D0/3.D0)
      PARAMETER (ANV43=4.D0/3.D0)
      PARAMETER (ANV53=5.D0/3.D0)
C     PARAMETER (CL10=1./LOG(10.))
      PARAMETER (CL10=1.D0/2.30258509299404568402D0)
      PARAMETER (CFF=((PLANCK/(2.D0*PIKON))**2)/ELMASS)
C     PARAMETER (CFG=(2.*EXP(1.))**ANV23)
      PARAMETER (CFG=3.09183506572446D0)
      PARAMETER (CF=CFG/(2.D28*CFF*PIKON))
      PARAMETER (ANVA=1.D24/AVOGAD)
      PARAMETER (ANVB=1.D12*BOLTS)
      PARAMETER (ANVC=1.D12)
      PARAMETER (ANVD=1.D-12*AVOGAD)
      PARAMETER (ANVE=1.0000001D0)
      PARAMETER (ZERO=0.D0)
      PARAMETER (ONE=1.D0)
      PARAMETER (TWO=2.D0)
      PARAMETER (THREEH=1.5D0)
C
      DIMENSION XB(20),YB(46),TC(13,528)
      DIMENSION SC(6864),NS(20)
      EQUIVALENCE (TC(1,1),SC(1))
      COMMON /ANZLTF/ ZLTOMF
      PARAMETER (NX=19)
      PARAMETER (XLM=-1.D0)
      PARAMETER (DXL=.5D0)
      PARAMETER (WLM=0.D0)
      PARAMETER (DWL=.2D0)
      PARAMETER (WMN=1.D0)
      PARAMETER (VFMN=.1D0)
      PARAMETER (VFMX=1.D8)
      PARAMETER (NYM=45)
      PARAMETER (NIS=528)
C
      DATA (NS(I),I=1,20) /1,17,34,52,72,93,117,142,168,196,226,
     2  256,290,325,362,401,442,485,529,0/
C
      DATA (XB(I),I=1,20)/           -2.30258509D+00,
     & -1.15129255D+00,0.D0,          1.15129255D+00,2.30258509D+00,
     &  3.45387764D+00,4.60517019D+00,5.75646273D+00,6.90775528D+00,
     &  8.05904782D+00,9.21034037D+00,1.03616329D+01,1.15129255D+01,
     &  1.26642180D+01,1.38155106D+01,1.49668031D+01,1.61180956D+01,
     &  1.72693882D+01,1.84206807D+01,0.D0/
C
      DATA (YB(I),I=1,46)/
     &  3.95195792D-02,6.19305160D-02,9.64516374D-02,1.48834103D-01,
     &  2.26613027D-01,3.38690255D-01,4.94015638D-01,6.99409135D-01,
     &  9.57357635D-01,1.26509907D+00,1.61563601D+00,1.99997101D+00,
     &  2.40925164D+00,2.83603555D+00,3.27466762D+00,3.72112559D+00,
     &  4.17266916D+00,4.62748261D+00,5.08438410D+00,5.54261313D+00,
     &  6.00168383D+00,6.46128721D+00,6.92122732D+00,7.38138017D+00,
     &  7.84166735D+00,8.30203932D+00,8.76246480D+00,9.22292407D+00,
     &  9.68340464D+00,1.01438987D+01,1.06044012D+01,1.10649090D+01,
     &  1.15254203D+01,1.19859337D+01,1.24464484D+01,1.29069639D+01,
     &  1.33674800D+01,1.38279965D+01,1.42885131D+01,1.47490299D+01,
     &  1.52095468D+01,1.56700637D+01,1.61305807D+01,1.65910977D+01,
     &  1.70516147D+01,0.D0/
C
      DATA (SC(I),I=1,45)/5.38936908D-02,-2.97785098D-05,6.61766950D-05,
     1-1.96828486D-04,-2.62290827D-06,-2.93303135D-07,1.22104135D-02,6.5
     21808544D-08,-6.75381595D-06,-4.46230297D-05,-1.49994052D-07,-1.477
     307303D-07,9.46769880D-01,8.53239365D-02,-4.73013465D-05,1.57919891
     4D-04,-3.12010972D-04,-4.16795386D-06,-7.85787026D-07,1.93289032D-0
     52,1.29844260D-07,-1.07690207D-05,-7.11268619D-05,-2.42527629D-07,-
     62.32293811D-07,9.46768420D-01,1.34958898D-01,-7.54100986D-05,3.637
     747113D-04,-4.95454261D-04,-6.64930060D-06,-2.22821912D-06,3.054025
     858D-02,-3.91391986D-07,-1.73397314D-05,-1.14429455D-04,-4.08109081
     9D-07,-3.57742848D-07,9.46764750D-01,2.13040866D-01,-1.21527795D-04
     $,7.76814093D-04,-7.91049993D-04,-1.07422947D-05,-7.19260605D-06/
      DATA (SC(I),I=46,90)/4.80093513D-02,-8.06291808D-06,-2.87779654D-0
     15,-1.89263542D-04,-7.76791663D-07,-5.03853455D-07,9.46755420D-01,3
     2.34639045D-01,-2.01473217D-04,1.38022615D-03,-1.29082421D-03,-1.78
     3496646D-05,-2.26543101D-05,7.43384485D-02,-5.82011073D-05,-5.11674
     4559D-05,-3.38179235D-04,-1.29565308D-06,-9.77386743D-07,9.46734680
     5D-01,5.18903614D-01,-3.45087744D-04,1.76589331D-03,-2.21955020D-03
     6,-3.04656664D-05,-3.78770655D-05,1.10679125D-01,-1.65521075D-04,-9
     7.24470717D-05,-6.22771360D-04,-8.71727900D-07,-3.16323317D-06,9.46
     8775860D-01,7.83324957D-01,-5.82860877D-04,1.52233680D-03,-3.842094
     943D-03,-5.12574688D-05,-1.11028022D-05,1.54122806D-01,-2.20851507D
     $-04,-1.45326061D-04,-9.61204103D-04,-2.90679430D-07,-6.07026070D-0
     $6/
      DATA (SC(I),I=91,135)/9.47557900D-01,1.13618113D+00,-9.06920810D-0
     14,8.70980844D-04,-6.02736991D-03,-8.10038917D-05,7.24206535D-05,1.
     298797895D-01,-1.70969864D-04,-1.78733872D-04,-1.07799173D-03,-1.46
     3515392D-06,-7.04711742D-06,9.50955130D-01,1.57432864D+00,-1.243928
     467D-03,2.64088313D-04,-8.03216032D-03,-1.16574554D-04,1.57417438D-
     504,2.39347405D-01,-9.67070401D-05,-1.58273986D-04,-7.64681298D-04,
     6-4.07374036D-06,-5.19931925D-06,9.58680610D-01,2.08624002D+00,-1.4
     77652823D-03,-1.62338037D-04,-8.97888840D-03,-1.49247927D-04,1.7874
     83166D-04,2.72517086D-01,-5.02344002D-05,-7.43255760D-05,-1.2073469
     96D-04,-6.19306086D-06,-8.70566243D-07,9.69769020D-01,2.65614227D+0
     $0,-1.51257488D-03,-4.35516414D-04,-8.51902604D-03,-1.66471159D-04/
      DATA (SC(I),I=136,180)/1.19886098D-04,2.97216978D-01,-1.87110272D-
     105,3.82789229D-05,5.02099775D-04,-5.09495508D-06,3.54696601D-06,9.
     280873370D-01,3.26786565D+00,-1.35233921D-03,-5.49413198D-04,-7.055
     305893D-03,-1.60681355D-04,3.24201417D-05,3.14246695D-01,4.29099612
     4D-06,1.21956750D-04,8.24139909D-04,-1.18798182D-06,5.63087296D-06,
     59.89258080D-01,3.90779341D+00,-1.08080645D-03,-5.13975866D-04,-5.2
     69199898D-03,-1.36195177D-04,-2.70154216D-05,3.25420706D-01,1.99671
     7121D-05,1.49576007D-04,8.38564106D-04,2.38217886D-06,5.41801912D-0
     86,9.94416460D-01,4.56604890D+00,-7.95573997D-04,-4.06173295D-04,-3
     9.71995889D-03,-1.04396484D-04,-4.79973141D-05,3.32614210D-01,2.317
     $69374D-05,1.35656448D-04,6.91977427D-04,3.88451465D-06/
      DATA (SC(I),I=181,225)/4.21463374D-06,9.97209250D-01,5.23605076D+0
     10,-5.54228490D-04,-2.88902955D-04,-2.51225195D-03,-7.47022508D-05,
     2-4.60353979D-05,3.37220852D-01,1.95449912D-05,1.05689059D-04,5.111
     351724D-04,3.75465523D-06,2.99331313D-06,9.98624820D-01,5.90838000D
     4+00,-4.85005112D-04,3.42070614D-04,6.44009258D-03,-2.31823080D-03,
     5-5.71313640D-04,3.32721944D-01,2.92865318D-03,-3.64656803D-05,1.15
     6902651D-02,-1.29238611D-03,1.63873869D-04,9.99323620D-01,5.3358452
     74D-02,-4.88647262D-05,6.53610769D-05,-3.50323601D-04,-3.73401928D-
     806,-5.22314896D-07,1.20931694D-02,5.27046437D-08,-1.10854513D-05,-
     97.94771280D-05,-2.13924409D-07,-2.09973053D-07,9.10498620D-01,8.44
     $746209D-02,-7.76341238D-05,1.55733193D-04,-5.55346255D-04/
      DATA (SC(I),I=226,270)/-5.93642409D-06,-1.40091026D-06,1.91420143D
     1-02,7.36106052D-08,-1.76839463D-05,-1.26697530D-04,-3.47593976D-07
     2,-3.29710966D-07,9.10495290D-01,1.33607604D-01,-1.23838084D-04,3.5
     37526695D-04,-8.81911869D-04,-9.48623324D-06,-3.99219864D-06,3.0239
     45698D-02,-6.77319475D-07,-2.85200140D-05,-2.03887007D-04,-5.950985
     574D-07,-5.02501063D-07,9.10486870D-01,2.10873740D-01,-1.99975745D-
     604,7.56373305D-04,-1.40792530D-03,-1.54158349D-05,-1.32481814D-05,
     74.75120688D-02,-9.84099847D-06,-4.76176468D-05,-3.37384242D-04,-1.
     824165160D-06,-6.25549610D-07,9.10465490D-01,3.31072246D-01,-3.3237
     90034D-04,1.31823624D-03,-2.30119838D-03,-2.58329156D-05,-3.9335604
     $4D-05,7.34509921D-02,-6.04563502D-05,-8.47766427D-05,-6.01895764D-
     $04/
      DATA (SC(I),I=271,315)/-2.07534712D-06,-1.26599201D-06,9.10416630D
     1-01,5.12779924D-01,-5.68340192D-04,1.66152339D-03,-3.94854944D-03,
     2-4.40073530D-05,-6.64928550D-05,1.09051072D-01,-1.54672407D-04,-1.
     351193515D-04,-1.10103487D-03,-1.30652551D-06,-4.43935406D-06,9.104
     451350D-01,7.72873082D-01,-9.55518509D-04,1.48218879D-03,-6.8181777
     53D-03,-7.28543541D-05,-2.90452079D-05,1.51596867D-01,-1.92264632D-
     604,-2.35984801D-04,-1.71560309D-03,-8.18824987D-08,-8.59573848D-06
     7,9.11612130D-01,1.11993851D+00,-1.49301201D-03,1.03849905D-03,-1.0
     87739934D-02,-1.13869206D-04,9.50975510D-05,1.95895708D-01,-1.41082
     9962D-04,-3.01508695D-04,-2.02636171D-03,-1.23415872D-06,-1.0595646
     $2D-05,9.16731480D-01,1.55253188D+00,-2.09635291D-03,6.65394686D-04
     $/
      DATA (SC(I),I=316,360)/-1.47349342D-02,-1.66818629D-04,2.43888935D
     1-04,2.37154318D-01,-8.53282482D-05,-3.01832208D-04,-1.65857228D-03
     2,-5.04054482D-06,-9.60436192D-06,9.28552280D-01,2.06131847D+00,-2.
     360154591D-03,3.39946340D-04,-1.71948729D-02,-2.25834562D-04,3.2354
     41211D-04,2.71967508D-01,-7.01618708D-05,-2.03360790D-04,-6.2711424
     59D-04,-9.75215027D-06,-5.11090959D-06,9.46157270D-01,2.63171200D+0
     60,-2.82587842D-03,-4.50704853D-05,-1.71744327D-02,-2.74086966D-04,
     72.70559831D-04,2.98397940D-01,-6.24468675D-05,-2.09717292D-05,5.98
     8322853D-04,-1.12445706D-05,1.98142845D-06,9.64806730D-01,3.2469259
     90D+00,-2.68469340D-03,-3.94559315D-04,-1.49212285D-02,-2.89988969D
     $-04,1.22433742D-04,3.16425530D-01,-3.77933344D-05,1.62156749D-04/
      DATA (SC(I),I=361,405)/1.43122792D-03,-6.45558485D-06,7.76772565D-
     106,9.79758210D-01,3.89162635D+00,-2.26070143D-03,-5.54346956D-04,-
     21.16121231D-02,-2.66265559D-04,-1.33556691D-05,3.27732145D-01,-3.2
     31493623D-06,2.61835226D-04,1.65731405D-03,9.97190185D-07,9.5523741
     41D-06,9.89382140D-01,4.55444397D+00,-1.73051240D-03,-5.34560901D-0
     54,-8.37041153D-03,-2.16707884D-04,-8.03902923D-05,3.34560704D-01,1
     6.75885472D-05,2.68353801D-04,1.46548701D-03,5.88259850D-06,8.34667
     7452D-06,9.94709490D-01,5.22810252D+00,-1.23856523D-03,-4.26350623D
     8-04,-5.74666699D-03,-1.61508468D-04,-9.14122703D-05,3.38673913D-01
     9,2.26004597D-05,2.23593374D-04,1.12665793D-03,7.06841356D-06,6.302
     $02142D-06,9.97417010D-01,5.90827423D+00,-8.48329323D-04/
      DATA (SC(I),I=406,450)/-3.06397712D-04,-3.82894264D-03,-1.13547988
     1D-04,-7.71546854D-05,3.41185321D-01,1.95933927D-05,1.66642530D-04,
     28.01350268D-04,6.16994640D-06,4.43985894D-06,9.98742860D-01,6.5924
     31971D+00,-5.65077674D-04,-2.07733197D-04,-2.50456511D-03,-7.693210
     438D-05,-5.73263917D-05,3.42741465D-01,1.45170056D-05,1.16609119D-0
     54,5.45037607D-04,4.68247858D-06,3.01565803D-06,9.99385760D-01,5.24
     6307532D-02,-7.38077533D-05,6.39500283D-05,-5.92691409D-04,-4.48212
     7380D-06,-8.88733712D-07,1.18880972D-02,3.17796082D-08,-1.67532594D
     8-05,-1.34592121D-04,-2.57975735D-07,-2.51464574D-07,8.53684090D-01
     9,8.30024303D-02,-1.17317493D-04,1.51933712D-04,-9.39656068D-04,-7.
     $13579051D-06,-2.39857067D-06,1.88150675D-02,-2.60013868D-08/
      DATA (SC(I),I=451,495)/-2.67564799D-05,-2.14632710D-04,-4.24658016
     1D-07,-3.92735029D-07,8.53676740D-01,1.31264805D-01,-1.87388915D-04
     2,3.46601350D-04,-1.49256797D-03,-1.14582326D-05,-6.93314667D-06,2.
     397132839D-02,-1.21153071D-06,-4.33149428D-05,-3.45751660D-04,-7.59
     4168053D-07,-5.84659946D-07,8.53658180D-01,2.07113697D-01,-3.038782
     564D-04,7.19848322D-04,-2.38520655D-03,-1.88723436D-05,-2.32768015D
     6-05,4.66396317D-02,-1.30753786D-05,-7.31744057D-05,-5.74781711D-04
     7,-1.68215778D-06,-6.81069700D-07,8.53610990D-01,3.24873627D-01,-5.
     807969915D-04,1.21308749D-03,-3.90984709D-03,-3.21916154D-05,-6.581
     931489D-05,7.18952809D-02,-6.45764378D-05,-1.30917246D-04,-1.025972
     $26D-03,-2.77354855D-06,-1.52285991D-06,8.53502540D-01,5.02150690D-
     $01/
      DATA (SC(I),I=496,540)/-8.66665520D-04,1.48893068D-03,-6.70793097D
     1-03,-5.44793156D-05,-1.06099857D-04,1.06220072D-01,-1.39175498D-04
     2,-2.27778359D-04,-1.85552546D-03,-1.11590781D-06,-5.73153385D-06,8
     3.53507690D-01,7.54781327D-01,-1.44119226D-03,1.39624830D-03,-1.151
     434543D-02,-8.70026178D-05,-5.68952823D-05,1.47183054D-01,-1.514694
     579D-04,-3.46748376D-04,-2.88470628D-03,1.23475557D-06,-1.06489650D
     6-05,8.55202370D-01,1.09165562D+00,-2.23973330D-03,1.24179793D-03,-
     71.82139144D-02,-1.31128259D-04,1.08201335D-04,1.90582172D-01,-9.53
     8711658D-05,-4.51792668D-04,-3.53797450D-03,4.22899757D-07,-1.30715
     9110D-05,8.62645740D-01,1.51369984D+00,-3.19157161D-03,1.23905934D-
     $03,-2.54072583D-02,-1.91918144D-04,3.29775723D-04,2.32563294D-01/
      DATA (SC(I),I=541,585)/-5.67772048D-05,-5.00045641D-04,-3.25503843
     1D-03,-4.01731333D-06,-1.37290179D-05,8.79844000D-01,2.01510447D+00
     2,-4.12758641D-03,1.17206626D-03,-3.08768280D-02,-2.74629375D-04,5.
     308578706D-04,2.69845756D-01,-7.86179151D-05,-4.35969159D-04,-1.861
     455984D-03,-1.15980328D-05,-1.20112513D-05,9.06254910D-01,2.5840323
     53D+00,-4.78047606D-03,7.54194988D-04,-3.26146698D-02,-3.70341454D-
     604,5.28705642D-04,2.99512853D-01,-1.17111835D-04,-2.16920497D-04,2
     7.22133100D-04,-1.91766200D-05,-5.07013541D-06,9.35988520D-01,3.203
     888737D+00,-4.89382312D-03,7.35528448D-05,-3.00594763D-02,-4.450804
     991D-04,3.45678418D-04,3.20006440D-01,-1.14436729D-04,1.03573444D-0
     $4,2.08120287D-03,-1.86105749D-05,5.48781189D-06,9.61722160D-01/
      DATA (SC(I),I=586,630)/3.85693037D+00,-4.42122825D-03,-4.83367457D
     1-04,-2.45885626D-02,-4.60532737D-04,8.43351685D-05,3.32182994D-01,
     2-6.15113131D-05,3.69021425D-04,2.98261591D-03,-7.59818230D-06,1.29
     3948222D-05,9.79466540D-01,4.52874505D+00,-3.57957116D-03,-7.127798
     452D-04,-1.83710512D-02,-4.11591442D-04,-9.78286585D-05,3.38628514D
     5-01,-6.38513525D-06,4.72635668D-04,2.93362189D-03,4.77562114D-06,1
     6.42983863D-05,9.89725430D-01,5.21012425D+00,-2.66641736D-03,-6.804
     735437D-04,-1.29164639D-02,-3.27391051D-04,-1.62672544D-04,3.418544
     829D-01,2.18345806D-05,4.40518132D-04,2.39690786D-03,1.09384282D-05
     9,1.20877599D-05,9.95021920D-01,5.89614546D+00,-1.87618798D-03,-5.3
     $9021671D-04,-8.74127116D-03,-2.40240292D-04,-1.55469273D-04/
      DATA (SC(I),I=631,675)/3.43468206D-01,2.79219719D-05,3.49711242D-0
     14,1.76769152D-03,1.14916967D-05,9.05749452D-06,9.97607050D-01,6.58
     2442069D+00,-1.27239626D-03,-3.87771098D-04,-5.77743344D-03,-1.6736
     38539D-04,-1.22711509D-04,3.44302470D-01,2.40936352D-05,2.54080479D
     4-04,1.22955455D-03,9.50408992D-06,6.38259565D-06,9.98845390D-01,7.
     527382485D+00,-8.42897244D-04,-2.64583088D-04,-3.76211553D-03,-1.12
     6851418D-04,-8.83790272D-05,3.44753348D-01,1.79395088D-05,1.7541853
     78D-04,8.26277469D-04,7.02950627D-06,4.34236841D-06,9.99438750D-01,
     85.09128555D-02,-1.00013043D-04,6.16260282D-05,-9.40565047D-04,-4.0
     94041970D-06,-1.43526643D-06,1.15491727D-02,-7.96669023D-09,-2.2723
     $8669D-05,-2.13833524D-04,-2.37995230D-07,-2.24633242D-07/
      DATA (SC(I),I=676,720)/7.70155010D-01,8.05931513D-02,-1.59135592D-
     104,1.45612248D-04,-1.49151509D-03,-6.46862492D-06,-3.92289394D-06,
     21.82744474D-02,-2.07557204D-07,-3.63986823D-05,-3.41304177D-04,-4.
     305164528D-07,-3.46309606D-07,7.70139540D-01,1.27428955D-01,-2.5509
     43221D-04,3.27693572D-04,-2.37001874D-03,-1.06017436D-05,-1.1974631
     56D-05,2.88420490D-02,-2.44632531D-06,-5.95589466D-05,-5.51015314D-
     604,-8.78987195D-07,-4.36098005D-07,7.70100450D-01,2.00944029D-01,-
     74.17028497D-04,6.58029633D-04,-3.79882837D-03,-1.80928542D-05,-3.8
     85418877D-05,4.51857893D-02,-1.80466371D-05,-1.02376330D-04,-9.2423
     97472D-04,-1.95750565D-06,-4.72964465D-07,7.70001080D-01,3.14666996
     $D-01,-7.03717164D-04,1.04396855D-03,-6.25942599D-03,-3.17949451D-0
     $5/
      DATA (SC(I),I=721,765)/-1.03305783D-04,6.92961024D-02,-6.82502662D
     1-05,-1.84312338D-04,-1.65728550D-03,-2.50340044D-06,-1.91717488D-0
     26,7.69776830D-01,4.84659454D-01,-1.19396233D-03,1.23233606D-03,-1.
     307473746D-02,-5.21534125D-05,-1.50494764D-04,1.01559081D-01,-1.158
     463284D-04,-3.05932824D-04,-2.93608706D-03,6.40911215D-07,-6.399569
     557D-06,7.69730080D-01,7.25206856D-01,-1.94370641D-03,1.25248826D-0
     63,-1.82569917D-02,-7.57762839D-05,-8.68647609D-05,1.39971623D-01,-
     79.75428636D-05,-4.43811260D-04,-4.49566452D-03,4.51340499D-06,-1.0
     85661824D-05,7.72204550D-01,1.04544393D+00,-2.96603692D-03,1.454403
     992D-03,-2.87027121D-02,-1.02844730D-04,1.04404655D-04,1.81622683D-
     $01,-3.54415807D-05,-5.78519252D-04,-5.63962484D-03,4.49446795D-06/
      DATA (SC(I),I=766,810)/-1.19759139D-05,7.82616090D-01,1.44920678D+
     100,-4.23842803D-03,1.94442387D-03,-4.05018348D-02,-1.44267783D-04,
     23.75588806D-04,2.23946141D-01,-8.12278405D-06,-6.93871857D-04,-5.6
     38448856D-03,6.92712738D-07,-1.39227930D-05,8.06145840D-01,1.935503
     418D+00,-5.67008622D-03,2.34410842D-03,-5.09436499D-02,-2.20726999D
     5-04,6.63463452D-04,2.64247708D-01,-5.79858676D-05,-7.37786328D-04,
     6-4.22375819D-03,-7.54836131D-06,-1.74511665D-05,8.42929540D-01,2.4
     79740333D+00,-7.01258262D-03,2.13182459D-03,-5.69044603D-02,-3.4926
     82641D-04,8.48923958D-04,2.98995628D-01,-1.54982480D-04,-6.04710078
     9D-04,-1.34668217D-03,-2.20485656D-05,-1.72197274D-05,8.86849770D-0
     $1,3.12076843D+00,-7.83853587D-03,1.18138342D-03,-5.61542023D-02/
      DATA (SC(I),I=811,855)/-5.12726978D-04,7.62152153D-04,3.24617535D-
     101,-2.17573245D-04,-2.21243169D-04,2.04500937D-03,-3.49668735D-05,
     2-7.49700230D-06,9.28396120D-01,3.78601876D+00,-7.76967908D-03,-1.2
     32967115D-06,-4.90502027D-02,-6.42902563D-04,3.97802617D-04,3.39778
     4735D-01,-1.79835239D-04,2.90099961D-04,4.52793219D-03,-3.05964376D
     5-05,7.97252093D-06,9.59911220D-01,4.47384742D+00,-6.82000218D-03,-
     68.10921036D-04,-3.85859102D-02,-6.71364775D-04,-3.12525348D-07,3.4
     76550695D-01,-8.02988038D-05,6.59576939D-04,5.31225315D-03,-9.52062
     8910D-06,1.79134400D-05,9.79543080D-01,5.17051604D+00,-5.39866288D-
     903,-1.07000071D-03,-2.81103807D-02,-5.96658790D-04,-2.26892733D-04
     $,3.48518245D-01,-4.44552041D-07,7.61762356D-04,4.78500013D-03/
      DATA (SC(I),I=856,900)/9.48497347D-06,1.94752081D-05,9.90092220D-0
     11,5.86886868D+00,-3.96108936D-03,-9.75367978D-04,-1.94728658D-02,-
     24.70955131D-04,-2.80877034D-04,3.48457352D-01,3.45510513D-05,6.758
     311171D-04,3.73589504D-03,1.73859926D-05,1.65056550D-05,9.95291820D
     4-01,6.56618287D+00,-2.76229426D-03,-7.57048344D-04,-1.30698595D-02
     5,-3.43784064D-04,-2.46565737D-04,3.47801907D-01,3.98998674D-05,5.2
     62983921D-04,2.68978623D-03,1.72377538D-05,1.24561320D-05,9.9776230
     70D-01,7.26185658D+00,-1.86427123D-03,-5.40662961D-04,-8.59971592D-
     803,-2.38882388D-04,-1.87700845D-04,3.47116790D-01,3.34821287D-05,3
     9.75039116D-04,1.84719719D-03,1.39205620D-05,8.83638991D-06,9.98927
     $890D-01,7.95605969D+00,-1.23198350D-03,-3.68630937D-04/
      DATA (SC(I),I=901,945)/-5.58658291D-03,-1.60913518D-04,-1.32889283
     1D-04,3.46567809D-01,2.47685231D-05,2.57248613D-04,1.23300061D-03,1
     2.01848780D-05,6.04260549D-06,9.99481400D-01,8.64914581D+00,-8.0300
     31244D-04,-2.44610083D-04,-3.59858314D-03,-1.06261060D-04,-9.032789
     484D-05,3.46171395D-01,1.71881829D-05,1.71733639D-04,8.08534217D-04
     5,7.06315656D-06,4.03558864D-06,9.99747020D-01,4.85987646D-02,-1.18
     6223821D-04,5.80034963D-05,-1.38228256D-03,-1.79115834D-06,-2.18726
     7541D-06,1.10273086D-02,-8.77879951D-08,-2.69330140D-05,-3.14741737
     8D-04,-1.19402550D-07,-9.28538857D-08,6.57632890D-01,7.69185698D-02
     9,-1.88597485D-04,1.35543408D-04,-2.19301578D-03,-2.97507630D-06,-6
     $.14594627D-06,1.74410415D-02,-5.43406257D-07,-4.34406495D-05/
      DATA (SC(I),I=946,990)/-5.03273820D-04,-2.44386075D-07,-1.35316471
     1D-07,6.57602030D-01,1.21570892D-01,-3.04422861D-04,2.96609162D-04,
     2-3.49023787D-03,-5.44932541D-06,-1.91097781D-05,2.74930121D-02,-4.
     329641204D-06,-7.23847270D-05,-8.17779309D-04,-6.69788092D-07,-1.87
     4633918D-07,6.57523900D-01,1.91486071D-01,-5.06278401D-04,5.5643966
     53D-04,-5.61769033D-03,-1.10060016D-05,-6.30480824D-05,4.29117576D-
     602,-2.36085076D-05,-1.29470812D-04,-1.39171423D-03,-1.60865505D-06
     7,-3.12261016D-07,6.57325650D-01,2.98919559D-01,-8.63976050D-04,7.9
     86981865D-04,-9.34950878D-03,-1.99794099D-05,-1.43680904D-04,6.5208
     96244D-02,-6.50457130D-05,-2.28226838D-04,-2.50135679D-03,-1.886429
     $68D-07,-2.37714512D-06,6.56904820D-01,4.57717711D-01,-1.44089493D-
     $03/
      DATA (SC(I),I=991,1035)/8.99194176D-04,-1.60293863D-02,-2.66194228
     1D-05,-1.82647118D-04,9.44140582D-02,-8.03541524D-05,-3.48692046D-0
     24,-4.28704967D-03,4.97993341D-06,-5.73415175D-06,6.56848600D-01,6.
     380188028D-01,-2.25691886D-03,1.06376630D-03,-2.67880328D-02,-2.251
     478032D-05,-1.01857203D-04,1.29152242D-01,-3.50331855D-05,-4.673318
     579D-04,-6.37826570D-03,9.49013993D-06,-6.68511180D-06,6.60532900D-
     601,9.75649661D-01,-3.32463886D-03,1.64241291D-03,-4.15274869D-02,-
     77.83676635D-06,8.36043331D-05,1.67960817D-01,2.99740604D-05,-6.003
     888126D-04,-8.07496732D-03,1.03864645D-05,-5.85097421D-06,6.7447994
     90D-01,1.35098795D+00,-4.69775584D-03,2.66432726D-03,-5.87557025D-0
     $2,3.74834771D-06,3.44314582D-04,2.09688414D-01,5.41183947D-05/
      DATA (SC(I),I=1036,1080)/-7.72728849D-04,-8.71658038D-03,8.8810751
     18D-06,-7.62400843D-06,7.04411830D-01,1.81062342D+00,-6.43660830D-0
     23,3.69153516D-03,-7.58138801D-02,-1.54465211D-05,6.83963290D-04,2.
     352659545D-01,-5.47836257D-07,-9.66123618D-04,-7.74580427D-03,3.980
     485470D-06,-1.48353558D-05,7.51196890D-01,2.35438657D+00,-8.4764899
     55D-03,4.03839764D-03,-8.90263630D-02,-1.07160218D-04,1.05764909D-0
     63,2.93626657D-01,-1.35765907D-04,-1.07375803D-03,-4.77951194D-03,-
     71.02826111D-05,-2.47197361D-05,8.09858620D-01,2.97408993D+00,-1.04
     8416398D-02,3.20900569D-03,-9.43337501D-02,-3.08540185D-04,1.265470
     912D-03,3.27639372D-01,-2.91138073D-04,-8.91391852D-04,-7.46995523D
     $-05,-3.75000895D-05,-2.81875467D-05,8.70653500D-01,3.65175073D+00/
      DATA (SC(I),I=1081,1125)/-1.16247397D-02,1.43540500D-03,-8.9275017
     17D-02,-5.91596358D-04,1.03883205D-03,3.50069046D-01,-3.46980144D-0
     24,-2.91708029D-04,4.88670986D-03,-6.04219723D-05,-1.54184782D-05,9
     3.22489730D-01,4.36332254D+00,-1.14276209D-02,-3.70471386D-04,-7.54
     4848115D-02,-8.30862828D-04,4.40762175D-04,3.60095147D-01,-2.484012
     551D-04,4.88826871D-04,8.02122485D-03,-5.02049695D-05,6.41218515D-0
     66,9.58611910D-01,5.08704114D+00,-9.92682534D-03,-1.42088599D-03,-5
     7.80391429D-02,-9.05997015D-04,-1.23992541D-04,3.61412680D-01,-9.20
     8420954D-05,1.01196866D-03,8.54478211D-03,-1.47914230D-05,2.1017113
     99D-05,9.79609350D-01,5.80956094D+00,-7.78853646D-03,-1.65815830D-0
     $3,-4.16914050D-02,-8.17168447D-04,-4.01913288D-04,3.58808341D-01/
      DATA (SC(I),I=1126,1170)/1.52686573D-05,1.12632022D-03,7.34073235D
     1-03,1.38335293D-05,2.43550638D-05,9.90348030D-01,6.52569701D+00,-5
     2.68232698D-03,-1.44438800D-03,-2.86563344D-02,-6.48567804D-04,-4.4
     30773919D-04,3.55363597D-01,5.64245262D-05,9.79889263D-04,5.5920689
     41D-03,2.47962180D-05,2.13155104D-05,9.95477910D-01,7.23491523D+00,
     5-3.95142375D-03,-1.09940209D-03,-1.91562211D-02,-4.74952367D-04,-3
     6.71038281D-04,3.52352893D-01,5.93792698D-05,7.51013960D-04,3.97574
     7903D-03,2.42801943D-05,1.64157959D-05,9.97870380D-01,7.93842344D+0
     80,-2.66410131D-03,-7.78934941D-04,-1.25796347D-02,-3.30935829D-04,
     9-2.77414720D-04,3.50080609D-01,4.84736872D-05,5.36308478D-04,2.713
     $14353D-03,1.95112942D-05,1.18009847D-05,9.98986440D-01/
      DATA (SC(I),I=1171,1215)/8.63772495D+00,-1.76044436D-03,-5.2975611
     10D-04,-8.16483208D-03,-2.23481666D-04,-1.94818128D-04,3.48482447D-
     201,3.55061836D-05,3.67348475D-04,1.80538441D-03,1.42731174D-05,8.1
     34168492D-06,9.99512360D-01,9.33410278D+00,-1.14788666D-03,-3.51521
     4896D-04,-5.25768422D-03,-1.47886526D-04,-1.31952129D-04,3.47400939
     5D-01,2.46173554D-05,2.45209223D-04,1.18216544D-03,9.91191198D-06,5
     6.47085558D-06,9.99763220D-01,4.53468586D-02,-1.18347628D-04,5.2626
     78045D-05,-1.86447179D-03,1.89239238D-06,-3.18942648D-06,1.02874267
     8D-02,-2.17725533D-07,-2.71361020D-05,-4.25453976D-04,7.49452126D-0
     98,1.13365318D-07,5.22197710D-01,7.17507635D-02,-1.90158508D-04,1.1
     $9768204D-04,-2.96015867D-03,2.55743127D-06,-9.62925688D-06/
      DATA (SC(I),I=1216,1260)/1.62570488D-02,-1.40047080D-06,-4.4674777
     16D-05,-6.82384116D-04,-8.76268764D-08,2.31835792D-07,5.22139400D-0
     21,1.13311143D-01,-3.13545358D-04,2.45660667D-04,-4.72482190D-03,2.
     358583059D-06,-3.18387172D-05,2.55616337D-02,-7.62304652D-06,-7.871
     420725D-05,-1.12295357D-03,-6.55586161D-07,5.25576908D-07,5.2199143
     50D-01,1.78051405D-01,-5.37282601D-04,4.00829993D-04,-7.68264482D-0
     63,1.28049717D-06,-9.25615870D-05,3.95936619D-02,-2.85040291D-05,-1
     7.45025170D-04,-1.95015744D-03,-8.37012085D-07,3.14354627D-07,5.216
     822060D-01,2.76359993D-01,-9.15925248D-04,4.86107305D-04,-1.2935617
     90D-02,4.46429108D-06,-1.67193656D-04,5.92576302D-02,-5.02802585D-0
     $5,-2.33617477D-04,-3.46298195D-03,3.65438975D-06,-1.53983533D-06/
      DATA (SC(I),I=1261,1305)/5.20943380D-01,4.19350532D-01,-1.45608861
     1D-03,5.42309256D-04,-2.19942077D-02,2.47257800D-05,-1.74237802D-04
     2,8.44131514D-02,-3.35971481D-05,-3.06545888D-04,-5.65940902D-03,1.
     303403035D-05,-2.32411349D-06,5.21152630D-01,6.17268727D-01,-2.1276
     47907D-03,8.72914659D-04,-3.58577341D-02,6.90755142D-05,-8.89944348
     5D-05,1.14516589D-01,2.42478141D-05,-3.65044573D-04,-8.11004231D-03
     6,1.38119626D-05,3.46714519D-07,5.26726470D-01,8.79569549D-01,-2.95
     7375975D-03,1.77477112D-03,-5.44403549D-02,1.34087116D-04,4.8753878
     87D-05,1.49403332D-01,8.45899724D-05,-4.61036108D-04,-1.02746741D-0
     92,1.47088204D-05,3.63830316D-06,5.44410520D-01,1.21571708D+00,-4.0
     $6272158D-03,3.24144824D-03,-7.66703137D-02,2.09305933D-04/
      DATA (SC(I),I=1306,1350)/2.32806396D-04,1.89123128D-01,1.12117982D
     1-04,-6.47925715D-04,-1.16648975D-02,1.58784976D-05,3.38378755D-06,
     25.79403300D-01,1.63494534D+00,-5.65906698D-03,4.89417262D-03,-1.00
     3550276D-01,2.76428194D-04,5.18674170D-04,2.33163196D-01,7.88934194
     4D-05,-9.48419689D-04,-1.17436082D-02,1.76016312D-05,-3.30278605D-0
     56,6.33095510D-01,2.14415954D+00,-7.92992029D-03,6.05957698D-03,-1.
     622865953D-01,2.97842037D-04,9.63530253D-04,2.79452435D-01,-4.40674
     7931D-05,-1.32243362D-03,-9.81850040D-03,1.39100791D-05,-1.75020029
     8D-05,7.02726990D-01,2.74391322D+00,-1.08445282D-02,5.97026349D-03,
     9-1.38901692D-01,2.03116794D-04,1.49578768D-03,3.23423960D-01,-2.53
     $361952D-04,-1.59217427D-03,-5.27807476D-03,-7.78504737D-06/
      DATA (SC(I),I=1351,1395)/-3.59856502D-05,7.80984670D-01,3.42362825
     1D+00,-1.38455197D-02,4.24934871D-03,-1.43204455D-01,-8.61432928D-0
     25,1.77511166D-03,3.58281821D-01,-4.57311565D-04,-1.40881726D-03,1.
     356117891D-03,-5.55107809D-05,-4.53485649D-05,8.56411950D-01,4.1599
     45407D+00,-1.58000482D-02,1.47210131D-03,-1.32724277D-01,-5.4351941
     50D-04,1.40181052D-03,3.78171577D-01,-4.92979645D-04,-5.45711228D-0
     64,8.47632689D-03,-9.67503776D-05,-3.10783354D-05,9.17060900D-01,4.
     792286519D+00,-1.57340957D-02,-1.02752024D-03,-1.10466323D-01,-9.65
     8118050D-04,5.17358291D-04,3.82989965D-01,-3.23017027D-04,6.1166374
     91D-04,1.24814988D-02,-8.13247678D-05,-1.64583924D-06,9.57112690D-0
     $1,5.68714596D+00,-1.37418082D-02,-2.32244944D-03,-8.40517562D-02/
      DATA (SC(I),I=1396,1440)/-1.14363810D-03,-2.62377858D-04,3.7842731
     16D-01,-1.00713999D-04,1.38062376D-03,1.27360980D-02,-2.68796049D-0
     25,2.05901887D-05,9.79370020D-01,6.43936486D+00,-1.08085948D-02,-2.
     350154215D-03,-6.00282125D-02,-1.06815204D-03,-6.16380232D-04,3.707
     441080D-01,3.89160988D-05,1.55258967D-03,1.07098312D-02,1.58987611D
     5-05,2.81336825D-05,9.90389060D-01,7.17620461D+00,-7.90136651D-03,-
     62.11544535D-03,-4.11506474D-02,-8.62692629D-04,-6.45004984D-04,3.6
     73451107D-01,8.75153050D-05,1.35463858D-03,8.07419780D-03,3.2450441
     81D-05,2.62468218D-05,9.95544970D-01,7.89942109D+00,-5.50591859D-03
     9,-1.59064758D-03,-2.74834609D-02,-6.38418235D-04,-5.34297916D-04,3
     $.57720068D-01,8.71387185D-05,1.04080933D-03,5.71376965D-03/
      DATA (SC(I),I=1441,1485)/3.25310702D-05,2.09088641D-05,9.97918690D
     1-01,8.61220890D+00,-3.71984867D-03,-1.12172204D-03,-1.80471672D-02
     2,-4.48012195D-04,-3.97147800D-04,3.53593503D-01,6.99509034D-05,7.4
     35260592D-04,3.89243997D-03,2.64270065D-05,1.53360791D-05,9.9901615
     40D-01,9.31758027D+00,-2.46276486D-03,-7.61901750D-04,-1.17173190D-
     502,-3.04125547D-04,-2.78427725D-04,3.50759660D-01,5.09931412D-05,5
     6.11823220D-04,2.58928231D-03,1.94635377D-05,1.07167012D-05,9.99529
     7570D-01,1.00178916D+01,-1.60848029D-03,-5.05643793D-04,-7.54862211
     8D-03,-2.02059744D-04,-1.88584073D-04,3.48867434D-01,3.51932517D-05
     9,3.42461344D-04,1.69590596D-03,1.35888078D-05,7.26385430D-06,9.997
     $72890D-01,1.07148353D+01,-1.04074464D-03,-3.30599690D-04/
      DATA (SC(I),I=1486,1530)/-4.83675195D-03,-1.32241253D-04,-1.250033
     197D-04,3.47624599D-01,2.38519758D-05,2.25274312D-04,1.09884108D-03
     2,9.23178408D-06,4.82479963D-06,9.99889520D-01,1.14095737D+01,-6.68
     3978063D-04,-2.13993261D-04,-3.08724906D-03,-8.56104991D-05,-8.1695
     42198D-05,3.46819163D-01,1.56024004D-05,1.46492262D-04,7.07261072D-
     504,6.09778567D-06,3.16100741D-06,9.99945940D-01,4.11585771D-02,-9.
     660818822D-05,4.48384997D-05,-2.30105463D-03,5.40663197D-06,-4.5988
     77830D-06,9.32752026D-03,-4.81006427D-07,-2.25535044D-05,-5.2707971
     87D-04,2.30893490D-07,3.24113832D-07,3.79611810D-01,6.50827123D-02,
     9-1.58445924D-04,9.49489205D-05,-3.66159045D-03,7.67224912D-06,-1.5
     $1900270D-05,1.47124669D-02,-2.89653991D-06,-3.98105378D-05/
      DATA (SC(I),I=1531,1575)/-8.53900323D-04,7.46146831D-08,5.03186567
     1D-07,3.79507030D-01,1.02590898D-01,-2.75091496D-04,1.63995487D-04,
     2-5.88765343D-03,9.76360168D-06,-4.98264629D-05,2.29961836D-02,-1.1
     38757955D-05,-7.68350339D-05,-1.43852391D-03,-2.38668204D-07,7.0654
     43234D-07,3.79240630D-01,1.60395954D-01,-4.84943417D-04,1.96512050D
     5-04,-9.73371177D-03,1.62819795D-05,-1.11756356D-04,3.50894947D-02,
     6-2.63783995D-05,-1.33016887D-04,-2.53619624D-03,2.50274767D-06,2.8
     78566185D-07,3.78618840D-01,2.46540037D-01,-7.86629411D-04,1.704923
     869D-04,-1.64833996D-02,3.95071316D-05,-1.48421281D-04,5.13798254D-
     902,-2.31921898D-05,-1.68669107D-04,-4.31903768D-03,8.58553575D-06,
     $2.35726464D-07,3.77806770D-01,3.69396333D-01,-1.11589224D-03/
      DATA (SC(I),I=1576,1620)/2.48791365D-04,-2.74395497D-02,8.85474230
     1D-05,-1.19280089D-04,7.18940485D-02,1.31764111D-05,-1.60593725D-04
     2,-6.63877062D-03,1.32106230D-05,2.48826042D-06,3.78982970D-01,5.37
     3487662D-01,-1.42366289D-03,7.28171166D-04,-4.33056292D-02,1.619822
     499D-04,-5.57490583D-05,9.69044589D-02,6.67949694D-05,-1.47176922D-
     504,-9.16493221D-03,1.44134421D-05,6.60511251D-06,3.87134340D-01,7.
     660235848D-01,-1.76117272D-03,1.82656476D-03,-6.41416942D-02,2.5505
     74641D-04,3.03976185D-06,1.27096941D-01,1.15894872D-04,-1.90332907D
     8-04,-1.16077989D-02,1.50497744D-05,1.04678418D-05,4.07860580D-01,1
     9.04862567D+00,-2.29406625D-03,3.54570527D-03,-8.95323794D-02,3.663
     $73108D-04,7.14506372D-05,1.63280266D-01,1.48750403D-04/
      DATA (SC(I),I=1621,1665)/-3.42560621D-04,-1.36999028D-02,1.7981558
     19D-05,1.21600584D-05,4.45016310D-01,1.41503248D+00,-3.28319924D-03
     2,5.63612348D-03,-1.18500290D-01,4.95186974D-04,2.23276693D-04,2.05
     3907314D-01,1.50030790D-04,-6.46572370D-04,-1.50477740D-02,2.446479
     419D-05,9.80052371D-06,5.00317830D-01,1.87182884D+00,-5.06346089D-0
     53,7.58817577D-03,-1.49055973D-01,6.31235851D-04,5.65068537D-04,2.5
     64387508D-01,8.38202140D-05,-1.13368928D-03,-1.49763272D-02,3.31454
     7474D-05,6.13675833D-07,5.73394590D-01,2.42826811D+00,-7.96592553D-
     803,8.64633720D-03,-1.77474873D-01,7.30875580D-04,1.18028603D-03,3.
     906021055D-01,-9.24787869D-05,-1.76877535D-03,-1.24489793D-02,3.415
     $08606D-05,-1.80901194D-05,6.60834090D-01,3.08528710D+00/
      DATA (SC(I),I=1666,1710)/-1.20493868D-02,7.98243293D-03,-1.9767203
     13D-01,6.84537713D-04,1.95797256D-03,3.54886630D-01,-3.76658717D-04
     2,-2.31468590D-03,-6.43804741D-03,5.62948245D-06,-4.48591574D-05,7.
     354745070D-01,3.82946561D+00,-1.65949056D-02,5.27286737D-03,-2.0215
     44913D-01,3.38626765D-04,2.39895554D-03,3.92139211D-01,-6.34720517D
     5-04,-2.23083294D-03,2.81038548D-03,-6.94620964D-05,-6.42637024D-05
     6,8.42433950D-01,4.63122025D+00,-1.99299576D-02,1.40015918D-03,-1.8
     76517708D-01,-3.19333878D-04,1.91032112D-03,4.10369307D-01,-6.56819
     8129D-04,-1.10421907D-03,1.22450916D-02,-1.41238323D-04,-5.40162000
     9D-05,9.10890110D-01,5.45327030D+00,-2.04887699D-02,-1.88920468D-03
     $,-1.54860792D-01,-9.99678639D-04,6.95622625D-04,4.10020360D-01/
      DATA (SC(I),I=1711,1755)/-4.13348518D-04,5.45406855D-04,1.76426883
     1D-02,-1.26882662D-04,-1.80351960D-05,9.54792030D-01,6.26560845D+00
     2,-1.82439099D-02,-3.48981196D-03,-1.17747314D-01,-1.35978165D-03,-
     33.71889581D-04,3.99001040D-01,-1.15371639D-04,1.69945315D-03,1.786
     401815D-02,-5.00212979D-05,1.48876496D-05,9.78564680D-01,7.05382813
     5D+00,-1.45271728D-02,-3.61398516D-03,-8.41462359D-02,-1.34416947D-
     603,-8.53534826D-04,3.85426931D-01,6.61759065D-05,2.01728386D-03,1.
     749781589D-02,1.30332092D-05,2.99065276D-05,9.90114650D-01,7.816197
     803D+00,-1.07100592D-02,-3.01699427D-03,-5.77623815D-02,-1.11759599
     9D-03,-8.92048778D-04,3.73528711D-01,1.26954244D-04,1.79982981D-03,
     $1.12934936D-02,3.93162819D-05,3.10307254D-05,9.95453470D-01/
      DATA (SC(I),I=1756,1800)/8.55688540D+00,-7.50958727D-03,-2.2595631
     19D-03,-3.86388277D-02,-8.41385633D-04,-7.40693358D-04,3.64465922D-
     201,1.23743549D-04,1.40064208D-03,8.00349109D-03,4.17817826D-05,2.5
     39763871D-05,9.97890840D-01,9.28135472D+00,-5.09743374D-03,-1.59273
     4826D-03,-2.54108333D-02,-5.97099140D-04,-5.52408787D-04,3.58035415
     5D-01,9.89122581D-05,1.01151146D-03,5.46245550D-03,3.47988994D-05,1
     6.95861774D-05,9.99009870D-01,9.99441323D+00,-3.38698006D-03,-1.082
     780253D-03,-1.65206306D-02,-4.08370097D-04,-3.88574660D-04,3.536515
     848D-01,7.21175736D-05,6.98942222D-04,3.63985837D-03,2.60583261D-05
     9,1.39211187D-05,9.99529860D-01,1.06997271D+01,-2.21824809D-03,-7.1
     $9566892D-04,-1.06549634D-02,-2.72858983D-04,-2.63963805D-04/
      DATA (SC(I),I=1801,1845)/3.50734615D-01,5.00552757D-05,4.69789745D
     1-04,2.38907306D-03,1.82353888D-05,9.54072326D-06,9.99774580D-01,1.
     213999010D+01,-1.43836604D-03,-4.71092416D-04,-6.83261253D-03,-1.79
     3579603D-04,-1.75403935D-04,3.48824153D-01,3.36625815D-05,3.1009230
     48D-04,1.55010777D-03,1.24784452D-05,6.38513296D-06,9.99891070D-01,
     51.20967134D+01,-9.26099573D-04,-3.05301426D-04,-4.36403232D-03,-1.
     616742071D-04,-1.14862806D-04,3.47586023D-01,2.21289811D-05,2.02174
     7160D-04,9.98251600D-04,8.34967994D-06,4.20550783D-06,9.99947040D-0
     81,3.62115800D-02,-5.75226699D-05,3.29689392D-05,-2.60803047D-03,7.
     911007987D-06,-7.27068217D-06,8.18581177D-03,-1.13448303D-06,-1.516
     $22710D-05,-6.02643879D-04,1.97925839D-07,4.31443797D-07/
      DATA (SC(I),I=1846,1890)/2.49997120D-01,5.71699546D-02,-1.05157363
     1D-04,5.46892667D-05,-4.17492633D-03,9.63508673D-06,-2.50696267D-05
     2,1.28480222D-02,-4.96990486D-06,-3.24724221D-05,-9.98377058D-04,1.
     325116017D-08,6.20622193D-07,2.49816140D-01,8.97127887D-02,-1.99489
     4043D-04,5.08048691D-05,-6.82691588D-03,1.54891875D-05,-6.33641545D
     5-05,1.98024635D-02,-1.22344900D-05,-6.18592579D-05,-1.73205945D-03
     6,1.52989041D-06,7.64026197D-07,2.49368160D-01,1.38894993D-01,-3.34
     7033789D-04,-9.70676118D-06,-1.14608999D-02,3.44972737D-05,-9.44624
     8553D-05,2.94780759D-02,-1.20674161D-05,-7.26854878D-05,-2.98314109
     9D-03,6.07571836D-06,1.13440815D-06,2.48530040D-01,2.10420649D-01,-
     $4.40458192D-04,-6.22135086D-05,-1.91712641D-02,7.46457781D-05/
      DATA (SC(I),I=1891,1935)/-8.42845968D-05,4.21050945D-02,8.47086920
     1D-06,-3.37389159D-05,-4.74796212D-03,1.01729229D-05,2.69120275D-06
     2,2.48164690D-01,3.10512256D-01,-4.35365162D-04,8.13395347D-05,-3.0
     38183253D-02,1.33228767D-04,-4.81717407D-05,5.80713473D-02,4.515376
     452D-05,3.88319463D-05,-6.87338921D-03,1.08468417D-05,5.58052726D-0
     56,2.51222660D-01,4.46410473D-01,-2.97187247D-04,6.43024137D-04,-4.
     669258362D-02,2.03917162D-04,-2.93979712D-05,7.81205536D-02,8.46694
     7906D-05,9.93459693D-05,-9.23023440D-03,1.00228797D-05,8.89394871D-
     806,2.61864930D-01,6.27081571D-01,-9.19833815D-05,1.78025269D-03,-6
     9.78391749D-02,2.87038540D-04,-4.93518355D-05,1.03275815D-01,1.2208
     $4519D-04,1.05857896D-04,-1.17428969D-02,1.05783758D-05/
      DATA (SC(I),I=1936,1980)/1.20654849D-05,2.83671580D-01,8.63701598D
     1-01,3.65923945D-05,3.52915763D-03,-9.38016290D-02,3.90773005D-04,-
     28.79982789D-05,1.34682774D-01,1.59682993D-04,2.27178802D-05,-1.431
     381779D-02,1.44340831D-05,1.47892886D-05,3.19195530D-01,1.16972985D
     4+00,-1.34576744D-04,5.77339177D-03,-1.24813389D-01,5.27225990D-04,
     5-8.60084002D-05,1.73409789D-01,1.91414855D-04,-1.93887019D-04,-1.6
     67378972D-02,2.25154427D-05,1.64876783D-05,3.70403320D-01,1.5603393
     76D+00,-9.30800596D-04,8.21336103D-03,-1.60265445D-01,7.08186863D-0
     84,6.01167203D-05,2.20053969D-01,1.90529788D-04,-6.02336832D-04,-1.
     985342758D-02,3.61501653D-05,1.53271500D-05,4.38674090D-01,2.050724
     $14D+00,-2.80630940D-03,1.03118203D-02,-1.98240497D-01/
      DATA (SC(I),I=1981,2025)/9.34653151D-04,4.85197068D-04,2.74008615D
     1-01,1.05629089D-04,-1.27317197D-03,-1.88163220D-02,5.42843934D-05,
     27.47143524D-06,5.24062290D-01,2.65248193D+00,-6.29100642D-03,1.124
     346278D-02,-2.34486389D-01,1.16489451D-03,1.30422229D-03,3.32181578
     4D-01,-1.20527585D-04,-2.21152505D-03,-1.61600545D-02,6.54708892D-0
     55,-1.21060368D-05,6.23628190D-01,3.36736272D+00,-1.16540718D-02,1.
     600708991D-02,-2.61397089D-01,1.25328688D-03,2.39907616D-03,3.87491
     7401D-01,-4.82320187D-04,-3.15154030D-03,-8.98047472D-03,3.61149439
     8D-05,-4.52836154D-05,7.29203770D-01,4.17969894D+00,-1.81459895D-02
     9,6.42987101D-03,-2.68872138D-01,9.42131450D-04,3.11939071D-03,4.28
     $987936D-01,-8.09906149D-04,-3.34037746D-03,2.79365107D-03/
      DATA (SC(I),I=2026,2070)/-6.78652141D-05,-7.85438268D-05,8.2704239
     10D-01,5.05378565D+00,-2.35391079D-02,1.42013275D-03,-2.50099898D-0
     21,1.16043568D-04,2.61371480D-03,4.47131958D-01,-8.39900914D-04,-2.
     305274094D-03,1.54081341D-02,-1.85531816D-04,-8.11030840D-05,9.0286
     46000D-01,5.94410074D+00,-2.54272968D-02,-2.80318864D-03,-2.0939100
     50D-01,-8.79625794D-04,1.05851291D-03,4.42220807D-01,-5.32911439D-0
     64,1.64552085D-04,2.30600018D-02,-1.87530367D-04,-4.36694142D-05,9.
     751053230D-01,6.81405616D+00,-2.33833409D-02,-4.85687145D-03,-1.603
     878201D-01,-1.51664575D-03,-3.89351464D-04,4.24319378D-01,-1.494855
     929D-04,1.87940377D-03,2.38033690D-02,-8.91337974D-05,1.82360165D-0
     $6,9.76918840D-01,7.64672298D+00,-1.90205891D-02,-4.99314134D-03/
      DATA (SC(I),I=2071,2115)/-1.15296497D-01,-1.63195672D-03,-1.084098
     129D-03,4.03908220D-01,8.96841533D-05,2.48334810D-03,2.02123647D-02
     2,1.36705522D-06,2.82876570D-05,9.89405080D-01,8.44127089D+00,-1.42
     3260602D-02,-4.17537999D-03,-7.95197200D-02,-1.41523309D-03,-1.1751
     42344D-03,3.86400993D-01,1.72245380D-04,2.31118079D-03,1.53743685D-
     502,4.35763106D-05,3.51307910D-05,9.95150760D-01,9.20429678D+00,-1.
     600749943D-02,-3.13861134D-03,-5.33901068D-02,-1.09158962D-03,-9.93
     7464293D-04,3.73169049D-01,1.69305696D-04,1.83988515D-03,1.09665784
     8D-02,5.15493138D-05,3.15653169D-05,9.97763180D-01,9.94384671D+00,-
     96.88759277D-03,-2.22071738D-03,-3.52136517D-02,-7.86567921D-04,-7.
     $49340191D-04,3.63805636D-01,1.36431325D-04,1.34751633D-03/
      DATA (SC(I),I=2116,2160)/7.52186028D-03,4.47079442D-05,2.46882762D
     1-05,9.98956840D-01,1.06668972D+01,-4.60017739D-03,-1.51474552D-03,
     2-2.29452859D-02,-5.43534466D-04,-5.31214828D-04,3.57426985D-01,9.9
     39670452D-05,9.39899045D-04,5.03129568D-03,3.41908630D-05,1.7929643
     48D-05,9.99508240D-01,1.13787460D+01,-3.02436349D-03,-1.00939251D-0
     53,-1.48247735D-02,-3.65684133D-04,-3.62896162D-04,3.53181796D-01,6
     6.96243899D-05,6.35914855D-04,3.31101937D-03,2.43461257D-05,1.24585
     7338D-05,9.99765990D-01,1.20831543D+01,-1.96670419D-03,-6.62308379D
     8-04,-9.52029088D-03,-2.41670829D-04,-2.42144147D-04,3.50399105D-01
     9,4.71559217D-05,4.21744450D-04,2.15332177D-03,1.67856454D-05,8.416
     $34723D-06,9.99887780D-01,1.27826920D+01,-1.26902535D-03/
      DATA (SC(I),I=2161,2205)/-4.29991363D-04,-6.08719457D-03,-1.576859
     152D-04,-1.59059740D-04,3.48595053D-01,3.10784825D-05,2.75934386D-0
     24,1.38994445D-03,1.12111096D-05,5.57933613D-06,9.99945840D-01,3.08
     3129752D-02,-1.69528763D-05,1.30511631D-05,-2.74334597D-03,6.149158
     467D-06,-1.26470939D-05,6.92388020D-03,-2.26162238D-06,-9.04954078D
     5-06,-6.49365499D-04,3.72997644D-08,3.67351484D-07,1.48551130D-01,4
     6.84341359D-02,-4.70436771D-05,-3.59567685D-06,-4.46412741D-03,9.99
     7854658D-06,-3.32153169D-05,1.07184284D-02,-5.44242832D-06,-2.10412
     8600D-05,-1.11361923D-03,9.45945785D-07,5.74096922D-07,1.48251910D-
     901,7.52513326D-02,-8.55899374D-05,-6.32148972D-05,-7.44515411D-03,
     $2.30435821D-05,-5.06556118D-05,1.60880986D-02,-4.96086319D-06/
      DATA (SC(I),I=2206,2250)/-1.75050002D-05,-1.91365631D-03,3.9367121
     11D-06,1.06576292D-06,1.47627410D-01,1.14691833D-01,-7.57481418D-05
     2,-1.46914763D-04,-1.24316926D-02,5.04289681D-05,-4.27455469D-05,2.
     332568719D-02,6.94926123D-06,2.73467958D-05,-3.08250337D-03,6.62862
     4324D-06,2.06159476D-06,1.46998950D-01,1.70703004D-01,6.09130897D-0
     55,-1.62334337D-04,-2.01076457D-02,8.81106754D-05,-1.58362320D-05,3
     6.25655784D-02,2.96902452D-05,1.09314436D-04,-4.56828901D-03,6.6393
     70173D-06,3.51133390D-06,1.47958240D-01,2.48073123D-01,3.72254903D-
     804,3.24324254D-05,-3.10263978D-02,1.28888508D-04,-7.35368611D-07,4
     9.46028042D-02,5.54710457D-05,2.02027377D-04,-6.33800652D-03,5.0653
     $0318D-06,5.17297738D-06,1.53071310D-01,3.52932418D-01/
      DATA (SC(I),I=2251,2295)/8.55272998D-04,5.88788700D-04,-4.57206430
     1D-02,1.71202914D-04,-2.48374653D-05,6.01935637D-02,8.07948164D-05,
     22.80990719D-04,-8.40708664D-03,3.92632725D-06,6.99259528D-06,1.647
     368760D-01,4.93246985D-01,1.46400728D-03,1.63334022D-03,-6.48005224
     4D-02,2.20976184D-04,-9.75606367D-05,8.03661178D-02,1.09907633D-04,
     53.27743558D-04,-1.08115134D-02,4.68318937D-06,9.28452321D-06,1.849
     690680D-01,6.79249283D-01,2.11346443D-03,3.23421766D-03,-8.89588152
     7D-02,2.89168575D-04,-2.06941690D-04,1.06327938D-01,1.49755337D-04,
     83.21713591D-04,-1.35595647D-02,7.75993001D-06,1.23685525D-05,2.155
     972840D-01,9.23750625D-01,2.66686485D-03,5.37286498D-03,-1.18881590
     $D-01,3.90491594D-04,-3.14518391D-04,1.39408746D-01/
      DATA (SC(I),I=2296,2340)/2.00150554D-04,2.31686832D-04,-1.65880228
     1D-02,1.44365560D-05,1.60964712D-05,2.58559150D-01,1.24219113D+00,2
     2.89924102D-03,7.92126379D-03,-1.55013581D-01,5.44746033D-04,-3.522
     313964D-04,1.80901644D-01,2.45990051D-04,6.89336412D-07,-1.96710408
     4D-02,2.67506544D-05,1.98435380D-05,3.16193980D-01,1.65211237D+00,2
     5.43939391D-03,1.05910077D-02,-1.97115131D-01,7.75725156D-04,-2.060
     609613D-04,2.31652566D-01,2.50632238D-04,-4.60536447D-04,-2.2277335
     70D-02,4.72919925D-05,2.16033762D-05,3.90531660D-01,2.17142139D+00,
     87.06265450D-04,1.28380975D-02,-2.43437249D-01,1.10200354D-03,2.892
     947462D-04,2.91232918D-01,1.53116099D-04,-1.27259201D-03,-2.3348171
     $9D-02,7.67443699D-05,1.74994536D-05,4.82296880D-01/
      DATA (SC(I),I=2341,2385)/2.81444314D+00,-3.07608603D-03,1.37679204
     1D-02,-2.89394582D-01,1.49976657D-03,1.29794519D-03,3.56462541D-01,
     2-1.14647329D-04,-2.50975947D-03,-2.10954139D-02,1.03537782D-04,1.0
     39991232D-06,5.89013090D-01,3.58476545D+00,-9.51961928D-03,1.228844
     488D-02,-3.26045272D-01,1.80957263D-03,2.73918709D-03,4.19490296D-0
     51,-5.51823108D-04,-3.93377379D-03,-1.33022456D-02,8.43141200D-05,-
     63.40487877D-05,7.02651540D-01,4.46600249D+00,-1.80718463D-02,7.899
     760801D-03,-3.40478398D-01,1.66687683D-03,3.86576046D-03,4.67427842
     8D-01,-9.65885716D-04,-4.61845322D-03,7.58442251D-04,-4.00884502D-0
     95,-8.15247810D-05,8.08833490D-01,5.41751398D+00,-2.61007288D-02,1.
     $77602091D-03,-3.22348004D-01,7.79236092D-04,3.52069664D-03/
      DATA (SC(I),I=2386,2430)/4.87993835D-01,-1.03900151D-03,-3.4104293
     10D-03,1.70731030D-02,-2.15695609D-04,-1.06511528D-04,8.91940080D-0
     21,6.38513959D+00,-3.01677179D-02,-3.55906846D-03,-2.74564229D-01,-
     35.39679635D-04,1.68715446D-03,4.80096973D-01,-6.94303134D-04,-6.56
     4559833D-04,2.80999053D-02,-2.59351065D-04,-7.78996612D-05,9.452600
     570D-01,7.32360454D+00,-2.90244679D-02,-6.30947297D-03,-2.13323195D
     6-01,-1.55433868D-03,-2.32233338D-04,4.55388633D-01,-2.20002493D-04
     7,1.79980988D-03,3.03294538D-02,-1.49000760D-04,-2.10780386D-05,9.7
     84102120D-01,8.21109506D+00,-2.43368018D-02,-6.61237975D-03,-1.5501
     93115D-01,-1.90150762D-03,-1.26187632D-03,4.27233220D-01,9.80923949
     $D-05,2.88785617D-03,2.64417442D-02,-2.45138405D-05,2.10081715D-05/
      DATA (SC(I),I=2431,2475)/9.88100880D-01,9.04634640D+00,-1.85764118
     1D-02,-5.61123441D-03,-1.07748074D-01,-1.74940814D-03,-1.47915878D-
     203,4.02942000D-01,2.18781765D-04,2.87253391D-03,2.04526264D-02,4.2
     31547239D-05,3.74006863D-05,9.94561840D-01,9.83810602D+00,-1.333859
     475D-02,-4.26362190D-03,-7.27542132D-02,-1.39435816D-03,-1.29356434
     5D-03,3.84485541D-01,2.23098697D-04,2.36528038D-03,1.47534910D-02,6
     6.06417975D-05,3.73277796D-05,9.97500700D-01,1.05972769D+01,-9.2061
     72326D-03,-3.04051171D-03,-4.81865622D-02,-1.02508511D-03,-9.945513
     858D-04,3.71369730D-01,1.83132075D-04,1.76719384D-03,1.01982794D-02
     9,5.59941214D-05,3.06728256D-05,9.98840730D-01,1.13334306D+01,-6.19
     $041950D-03,-2.08595531D-03,-3.14966996D-02,-7.17717127D-04/
      DATA (SC(I),I=2476,2520)/-7.13666633D-04,3.62403902D-01,1.35828018
     1D-04,1.24850992D-03,6.86017183D-03,4.41156346D-05,2.29014123D-05,9
     2.99457130D-01,1.20538966D+01,-4.08982674D-03,-1.39601757D-03,-2.03
     3979182D-02,-4.87201759D-04,-4.91565048D-04,3.56419965D-01,9.561984
     407D-05,8.52082839D-04,4.53249175D-03,3.20516492D-05,1.61889879D-05
     5,9.99743580D-01,1.27639114D+01,-2.66916700D-03,-9.18957476D-04,-1.
     631229340D-02,-3.24003302D-04,-3.29906373D-04,3.52490781D-01,6.4815
     72424D-05,5.68576905D-04,2.95726201D-03,2.22975989D-05,1.10609924D-
     805,9.99877980D-01,1.34670688D+01,-1.72693732D-03,-5.98079024D-04,-
     98.40205596D-03,-2.12444919D-04,-2.17624559D-04,3.49937256D-01,4.31
     $886117D-05,3.73652773D-04,1.91309565D-03,1.50308708D-05/
      DATA (SC(I),I=2521,2565)/7.38972911D-06,9.99941570D-01,1.41657735D
     1+01,-1.11033362D-03,-3.86127352D-04,-5.36032051D-03,-1.37948628D-0
     24,-1.41865431D-04,3.48291400D-01,2.81984386D-05,2.42950934D-04,1.2
     32967621D-03,9.96475838D-06,4.86278748D-06,9.99971880D-01,2.5284248
     41D-02,1.53706190D-05,-1.63917514D-05,-2.73476301D-03,4.99915135D-0
     56,-1.67958206D-05,5.58730275D-03,-2.34647141D-06,-2.25164040D-06,-
     66.76934532D-04,6.09406434D-07,3.21779225D-07,7.97618360D-02,3.9323
     74498D-02,2.05835997D-05,-6.06781419D-05,-4.54489705D-03,1.30495941
     8D-05,-2.38671482D-05,8.40614602D-03,-1.40001209D-06,7.46462109D-06
     9,-1.15419724D-03,2.37169749D-06,7.22338243D-07,7.93481850D-02,6.00
     $757560D-02,7.40166698D-05,-1.29500389D-04,-7.55675030D-03/
      DATA (SC(I),I=2566,2610)/2.91763145D-05,-1.56298800D-05,1.22196020
     1D-02,5.70285295D-06,4.59684490D-05,-1.85548883D-03,3.71511665D-06,
     21.25420778D-06,7.88550220D-02,8.98037915D-02,2.32248303D-04,-1.847
     377058D-04,-1.22100474D-02,4.91281289D-05,4.88325256D-06,1.72702022
     4D-02,1.90201731D-05,1.12263184D-04,-2.77159328D-03,3.23750512D-06,
     51.76907767D-06,7.91326380D-02,1.31359243D-01,5.38103918D-04,-1.575
     645908D-04,-1.89186346D-02,6.68110587D-05,2.06246615D-05,2.39529879
     7D-02,3.46164480D-05,1.93592432D-04,-3.91194079D-03,1.58500782D-06,
     82.24987425D-06,8.15964760D-02,1.88488439D-01,1.01084385D-03,4.4304
     97211D-05,-2.81405763D-02,8.01185106D-05,1.26076643D-05,3.28210176D
     $-02,4.96849229D-05,2.79147500D-04,-5.32073614D-03/
      DATA (SC(I),I=2611,2655)/1.67283411D-08,2.80211554D-06,8.76184870D
     1-02,2.66170826D-01,1.65278896D-03,5.29747184D-04,-4.04473030D-02,9
     2.17086223D-05,-3.42040507D-05,4.45892300D-02,6.59522815D-05,3.6279
     37610D-04,-7.06466053D-03,-6.89393723D-07,3.66560570D-06,9.83448230
     4D-02,3.70997027D-01,2.45422183D-03,1.40751630D-03,-5.65616950D-02,
     51.07321544D-04,-1.28263279D-04,6.01577412D-02,8.96132616D-05,4.386
     635265D-04,-9.21700099D-03,-3.57801517D-07,5.18805045D-06,1.1495062
     70D-01,5.11594036D-01,3.39010683D-03,2.76056743D-03,-7.73706452D-02
     8,1.35337325D-04,-2.66708539D-04,8.06388956D-02,1.27924926D-04,4.97
     9249727D-04,-1.18462127D-02,1.43552936D-06,7.74211233D-06,1.3889737
     $0D-01,6.99069086D-01,4.40562169D-03,4.62588435D-03/
      DATA (SC(I),I=2656,2700)/-1.03892427D-01,1.87724378D-04,-4.3246223
     19D-04,1.07373599D-01,1.84432766D-04,5.18265133D-04,-1.49889098D-02
     2,5.40845298D-06,1.16074317D-05,1.72074580D-01,9.47396254D-01,5.388
     332615D-03,6.98186737D-03,-1.37179208D-01,2.81645697D-04,-5.8718245
     43D-04,1.41889559D-01,2.52855049D-04,4.64439328D-04,-1.86066079D-02
     5,1.32350786D-05,1.67096962D-05,2.16857110D-01,1.27358133D+00,6.120
     605603D-03,9.72400941D-03,-1.78086418D-01,4.42440091D-04,-6.6098872
     75D-04,1.85739858D-01,3.13215518D-04,2.67290554D-04,-2.24937336D-02
     8,2.80277228D-05,2.24246994D-05,2.75908680D-01,1.69725980D+00,6.198
     929499D-03,1.25949278D-02,-2.26797317D-01,7.06176482D-04,-5.3241719
     $9D-04,2.40093032D-01,3.25045834D-04,-1.89051590D-04/
      DATA (SC(I),I=2701,2745)/-2.61067643D-02,5.40678624D-05,2.73479111
     1D-05,3.51695750D-01,2.23903169D+00,4.93318639D-03,1.50567530D-02,-
     22.81910817D-01,1.11461693D-03,-9.11258122D-06,3.04857726D-01,2.230
     312627D-04,-1.07605702D-03,-2.82950164D-02,9.45982801D-05,2.8206171
     46D-05,4.45473870D-01,2.91638696D+00,1.30267960D-03,1.61591892D-02,
     5-3.38869265D-01,1.67803294D-03,1.13155332D-03,3.77078510D-01,-7.10
     6358215D-05,-2.55444977D-03,-2.69940107D-02,1.40467145D-04,1.843640
     795D-05,5.55381680D-01,3.73595432D+00,-5.73251369D-03,1.46556227D-0
     82,-3.87912263D-01,2.25892934D-03,2.89025420D-03,4.48662055D-01,-5.
     970543499D-04,-4.48074352D-03,-1.93724736D-02,1.43889711D-04,-1.234
     $50665D-05,6.73901300D-01,4.68275191D+00,-1.60801793D-02/
      DATA (SC(I),I=2746,2790)/9.81589740D-03,-4.13634413D-01,2.42177800
     1D-03,4.51917986D-03,5.05296131D-01,-1.08211173D-03,-5.86692206D-03
     2,-3.74219664D-03,1.87543279D-05,-6.88746428D-05,7.86688430D-01,5.7
     31349115D+00,-2.70481016D-02,2.70275224D-03,-4.01335133D-01,1.64840
     4086D-03,4.57466624D-03,5.31621788D-01,-1.24178717D-03,-5.10100023D
     5-03,1.63574472D-02,-2.14429434D-04,-1.22138821D-04,8.77115000D-01,
     66.76601029D+00,-3.41646984D-02,-3.90521397D-03,-3.50340817D-01,7.9
     76074921D-05,2.63649234D-03,5.23551365D-01,-9.03596680D-04,-2.01559
     8664D-03,3.19181320D-02,-3.30851401D-04,-1.16977029D-04,9.36694210D
     9-01,7.78437812D+00,-3.48736047D-02,-7.67653719D-03,-2.77883624D-01
     $,-1.39133912D-03,1.97718881D-04,4.93002757D-01,-3.45113126D-04/
      DATA (SC(I),I=2791,2835)/1.30669042D-03,3.70041391D-02,-2.31862812
     1D-04,-5.57820630D-05,9.69690120D-01,8.73876307D+00,-3.04393280D-02
     2,-8.40766817D-03,-2.05052715D-01,-2.09961042D-03,-1.31727498D-03,4
     3.56486213D-01,7.56890566D-05,3.12758622D-03,3.36048029D-02,-7.1395
     45837D-05,4.90480806D-06,9.85980460D-01,9.62523168D+00,-2.38676178D
     5-02,-7.33198305D-03,-1.44086020D-01,-2.10041090D-03,-1.77479681D-0
     63,4.24152120D-01,2.58557270D-04,3.44412403D-03,2.66517605D-02,3.02
     7529020D-05,3.58376333D-05,9.93577990D-01,1.04538879D+01,-1.7448911
     82D-02,-5.67147876D-03,-9.80396741D-02,-1.74949456D-03,-1.63641569D
     9-03,3.99204557D-01,2.82777574D-04,2.97458254D-03,1.95363273D-02,6.
     $69345433D-05,4.24330895D-05,9.97051560D-01,1.12385966D+01/
      DATA (SC(I),I=2836,2880)/-1.21911605D-02,-4.09348343D-03,-6.529285
     149D-02,-1.31992210D-03,-1.29386149D-03,3.81301994D-01,2.39669132D-
     204,2.28316818D-03,1.36501877D-02,6.80624667D-05,3.73561323D-05,9.9
     38637090D-01,1.19919633D+01,-8.26768816D-03,-2.83188322D-03,-4.2850
     46822D-02,-9.39466659D-04,-9.44300597D-04,3.68981859D-01,1.81282378
     5D-04,1.64030413D-03,9.25180568D-03,5.58888639D-05,2.89202564D-05,9
     6.99365020D-01,1.27238242D+01,-5.49543866D-03,-1.90652123D-03,-2.78
     7340763D-02,-6.44858968D-04,-6.57657379D-04,3.60722141D-01,1.287181
     896D-04,1.13194536D-03,6.14522601D-03,4.16047979D-05,2.08899276D-05
     9,9.99701930D-01,1.34412878D+01,-3.60237128D-03,-1.26044104D-03,-1.
     $79473966D-02,-4.32128523D-04,-4.44737456D-04,3.55277437D-01/
      DATA (SC(I),I=2881,2925)/8.83186179D-05,7.61122021D-04,4.02501410D
     1-03,2.93971792D-05,1.44733178D-05,9.99859140D-01,1.41492708D+01,-2
     2.33832848D-03,-8.22950738D-04,-1.15107234D-02,-2.84860725D-04,-2.9
     34957954D-04,3.51731776D-01,5.88820413D-05,5.02920778D-04,2.6114919
     42D-03,2.00016162D-05,9.76178571D-06,9.99933040D-01,1.48510812D+01,
     5-1.50710436D-03,-5.32578607D-04,-7.35325068D-03,-1.85694155D-04,-1
     6.93027582D-04,3.49439911D-01,3.89821568D-05,3.28303345D-04,1.68223
     7066D-03,1.33538674D-05,6.46601583D-06,9.99968010D-01,1.55489053D+0
     81,-9.66331160D-04,-3.42478594D-04,-4.68370793D-03,-1.20014715D-04,
     9-1.25138679D-04,3.47969418D-01,2.51419547D-05,2.12469852D-04,1.078
     $04759D-03,8.79048167D-06,4.22935480D-06,9.99984650D-01/
      DATA (SC(I),I=2926,2970)/1.98763447D-02,4.93443194D-05,-4.29720048
     1D-05,-2.62419922D-03,6.61358970D-06,-9.78443291D-06,4.22492409D-03
     2,5.61316477D-08,1.46666396D-05,-6.58860711D-04,1.32174228D-06,4.08
     3067959D-07,3.88647000D-02,3.03557128D-02,1.06667089D-04,-8.7224625
     44D-05,-4.33807811D-03,1.48185327D-05,-2.67933526D-06,6.14859861D-0
     53,4.21388365D-06,4.26561300D-05,-1.04803737D-03,1.76512495D-06,6.0
     67536330D-07,3.85641540D-02,4.54333291D-02,2.36743237D-04,-1.339028
     708D-04,-6.97087777D-03,2.31538458D-05,1.12274612D-05,8.73648210D-0
     83,1.15673618D-05,8.74200176D-05,-1.56310485D-03,1.13317039D-06,6.6
     91824848D-07,3.86796430D-02,6.66801589D-02,4.67974300D-04,-1.557979
     $43D-04,-1.07836282D-02,2.76617317D-05,2.40958622D-05/
      DATA (SC(I),I=2971,3015)/1.22252614D-02,2.03927193D-05,1.43811046D
     1-04,-2.22425873D-03,-1.61603290D-07,6.20551034D-07,3.99276300D-02,
     29.62061352D-02,8.20536416D-04,-1.10534835D-04,-1.60925717D-02,2.67
     3091428D-05,2.63864117D-05,1.69438876D-02,2.91354988D-05,2.08751069
     4D-04,-3.07272112D-03,-1.50542518D-06,5.70182967D-07,4.29820370D-02
     5,1.36859773D-01,1.31135042D-03,6.46073990D-05,-2.33090026D-02,2.09
     6985280D-05,7.69501364D-06,2.33271051D-02,3.78380242D-05,2.82062932
     7D-04,-4.16663068D-03,-2.52906365D-06,6.08998471D-07,4.84237950D-02
     8,1.92474486D-01,1.95770865D-03,4.52263258D-04,-3.29709990D-02,1.26
     9562289D-05,-4.32798758D-05,3.19419410D-02,4.91258789D-05,3.6429529
     $7D-04,-5.57723928D-03,-3.15464311D-06,9.03558771D-07/
      DATA (SC(I),I=3016,3060)/5.68913950D-02,2.68184443D-01,2.77748773D
     1-03,1.14341960D-03,-4.57756868D-02,4.83860620D-06,-1.35833423D-04,
     24.35218881D-02,6.83793500D-05,4.55483784D-04,-7.38777792D-03,-3.36
     3441542D-06,1.70668840D-06,6.92267630D-02,3.70819129D-01,3.78505464
     4D-03,2.21951586D-03,-6.26058777D-02,2.27879085D-06,-2.74343027D-04
     5,5.90105202D-02,1.02428493D-04,5.52083129D-04,-9.69001046D-03,-3.0
     63190716D-06,3.40972651D-06,8.65859860D-02,5.09366681D-01,4.9824976
     78D-03,3.73943143D-03,-8.45465811D-02,1.22074972D-05,-4.53990684D-0
     84,7.96011508D-02,1.55924351D-04,6.45359915D-04,-1.25762283D-02,-1.
     973434757D-06,6.32088138D-06,1.10545130D-01,6.95477441D-01,6.343459
     $31D-03,5.73641994D-03,-1.12866738D-01,4.60674054D-05/
      DATA (SC(I),I=3061,3105)/-6.58264971D-04,1.06761681D-01,2.28030642
     1D-04,7.15601712D-04,-1.61184596D-02,1.70291727D-06,1.06405030D-05,
     21.43139800D-01,9.43946611D-01,7.78269516D-03,8.21034129D-03,-1.489
     336544D-01,1.22110031D-04,-8.52679400D-04,1.42203892D-01,3.10252185
     4D-04,7.23634137D-04,-2.03191305D-02,9.29660145D-06,1.63812909D-05,
     51.86865830D-01,1.27301744D+00,9.10073444D-03,1.10925836D-02,-1.940
     616807D-01,2.70365918D-04,-9.69926991D-04,1.87739132D-01,3.81752327
     7D-04,5.94405146D-04,-2.50190634D-02,2.50416731D-05,2.34083782D-05,
     82.44560540D-01,1.70413867D+00,9.88945834D-03,1.41627765D-02,-2.487
     984771D-01,5.38199160D-04,-8.84863985D-04,2.44878774D-01,4.03038816
     $D-04,1.94318754D-04,-2.97088689D-02,5.45437779D-05/
      DATA (SC(I),I=3106,3150)/3.09227918D-05,3.18967800D-01,2.26046266D
     1+00,9.39426008D-03,1.69046819D-02,-3.12377439D-01,9.90460122D-04,-
     23.86060582D-04,3.13972230D-01,3.07054237D-04,-6.89517021D-04,-3.32
     3258455D-02,1.03839102D-04,3.68248087D-05,4.11753680D-01,2.96287553
     4D+00,6.39902357D-03,1.83478973D-02,-3.80666293D-01,1.68010172D-03,
     58.02020401D-04,3.92564401D-01,7.63809287D-06,-2.30571949D-03,-3.33
     6589323D-02,1.68506454D-04,3.56504354D-05,5.21707660D-01,3.82207999
     7D+00,-5.65039991D-04,1.71248716D-02,-4.43779298D-01,2.52618374D-03
     8,2.78979438D-03,4.72903505D-01,-5.30041857D-04,-4.65834407D-03,-2.
     967932002D-02,2.03645042D-04,1.52390785D-05,6.42241190D-01,4.826793
     $38D+00,-1.20767552D-02,1.22201789D-02,-4.84647765D-01/
      DATA (SC(I),I=3151,3195)/3.09064415D-03,4.94276037D-03,5.40084510D
     1-01,-1.13756787D-03,-6.85337110D-03,-1.07424659D-02,1.03873172D-04
     2,-4.05270888D-05,7.59836260D-01,5.93426457D+00,-2.58640576D-02,4.3
     37631351D-03,-4.84109797D-01,2.64440146D-03,5.64503515D-03,5.758933
     426D-01,-1.42563819D-03,-6.93393135D-03,1.25534095D-02,-1.66806907D
     5-04,-1.19660522D-04,8.57485050D-01,7.07638061D+00,-3.67289809D-02,
     6-3.57633003D-03,-4.35681014D-01,1.00288779D-03,3.90248828D-03,5.71
     7715432D-01,-1.15479801D-03,-3.93099198D-03,3.34904277D-02,-3.81525
     8549D-04,-1.52763857D-04,9.24541010D-01,8.18543470D+00,-4.04274795D
     9-02,-8.72492376D-03,-3.54910533D-01,-9.36405395D-04,1.00001939D-03
     $,5.37583295D-01,-5.39931800D-04,2.32493456D-04,4.31106181D-02/
      DATA (SC(I),I=3196,3240)/-3.33433612D-04,-1.01923575D-04,9.6313172
     10D-01,9.22003073D+00,-3.71453473D-02,-1.02592777D-02,-2.67218541D-
     201,-2.14641349D-03,-1.15249783D-03,4.92733732D-01,2.44020079D-06,3
     3.04963868D-03,4.14638016D-02,-1.46060331D-04,-2.35865279D-05,9.827
     434340D-01,1.01702754D+01,-3.01468270D-02,-9.31800602D-03,-1.904460
     507D-01,-2.42874528D-03,-2.01011157D-03,4.51172202D-01,2.79009573D-
     604,3.94888163D-03,3.40362362D-02,1.04775462D-06,2.74332092D-05,9.9
     72041670D-01,1.10460284D+01,-2.25500455D-02,-7.39386905D-03,-1.3086
     86074D-01,-2.14787803D-03,-2.00652413D-03,4.18285671D-01,3.43529141
     9D-04,3.64789994D-03,2.54935592D-02,6.65881646D-05,4.53644944D-05,9
     $.96339100D-01,1.18638720D+01,-1.59993364D-02,-5.42594979D-03/
      DATA (SC(I),I=3241,3285)/-8.77619768D-02,-1.67674126D-03,-1.649765
     197D-03,3.94326113D-01,3.05518920D-04,2.90280909D-03,1.80653365D-02
     2,7.93826956D-05,4.42330323D-05,9.98309370D-01,1.26398212D+01,-1.09
     3653625D-02,-3.79583981D-03,-5.78858925D-02,-1.21878509D-03,-1.2316
     46120D-03,3.77676636D-01,2.37034600D-04,2.13116490D-03,1.23609858D-
     502,6.94028445D-05,3.59595128D-05,9.99214640D-01,1.33867467D+01,-7.
     634282542D-03,-2.57536880D-03,-3.77390442D-02,-8.48075225D-04,-8.70
     7190303D-04,3.66438424D-01,1.71332154D-04,1.49137213D-03,8.26606130
     8D-03,5.32877400D-05,2.67048335D-05,9.99632910D-01,1.41141124D+01,-
     94.83911902D-03,-1.71206390D-03,-2.44007564D-02,-5.73683226D-04,-5.
     $94155208D-04,3.58997115D-01,1.18466655D-04,1.01233427D-03/
      DATA (SC(I),I=3286,3330)/5.44036024D-03,3.83779511D-05,1.88254750D
     1-05,9.99827410D-01,1.48285362D+01,-3.15341497D-03,-1.12231316D-03,
     2-1.56818726D-02,-3.80713478D-04,-3.96706967D-04,3.54132319D-01,7.9
     39416725D-05,6.73369784D-04,3.54231661D-03,2.64366769D-05,1.2844770
     47D-05,9.99918430D-01,1.55345046D+01,-2.03836376D-03,-7.28486189D-0
     54,-1.00336775D-02,-2.49334631D-04,-2.60868915D-04,3.50982113D-01,5
     6.27741853D-05,4.41681426D-04,2.28759259D-03,1.78314821D-05,8.57649
     7367D-06,9.99961270D-01,1.48489695D-02,9.07538874D-05,-5.09884389D-
     805,-2.36691179D-03,6.54829647D-06,1.76799880D-06,2.97975512D-03,2.
     979403739D-06,3.15181733D-05,-5.59809738D-04,6.66747612D-07,2.11469
     $057D-07,1.73696300D-02,2.22036518D-02,1.80432554D-04/
      DATA (SC(I),I=3331,3375)/-7.99163098D-05,-3.77113785D-03,8.7935505
     13D-06,9.98765085D-06,4.24694039D-03,6.58612418D-06,5.81604932D-05,
     2-8.29747855D-04,1.36471006D-07,1.07939357D-07,1.74614340D-02,3.262
     348873D-02,3.30685564D-04,-1.04268377D-04,-5.80415608D-03,7.7461461
     43D-06,1.84069691D-05,5.98187769D-03,1.12262713D-05,9.20925168D-05,
     5-1.18463649D-03,-7.05001676D-07,-6.31108871D-08,1.81271820D-02,4.7
     62277090D-02,5.56147119D-04,-1.08398883D-04,-8.65815705D-03,2.44740
     7113D-06,2.33031978D-05,8.36400364D-03,1.61220327D-05,1.33369039D-0
     84,-1.65325963D-03,-1.61722446D-06,-2.64035480D-07,1.96616790D-02,6
     9.75365854D-02,8.73144513D-04,-6.45469564D-05,-1.25898441D-02,-7.22
     $280396D-06,1.96014665D-05,1.16346087D-02,2.09965969D-05/
      DATA (SC(I),I=3376,3420)/1.83628355D-04,-2.27504579D-03,-2.4738427
     10D-06,-4.79999905D-07,2.23313460D-02,9.56268738D-02,1.30195609D-03
     2,7.21640760D-05,-1.79409059D-02,-2.09404691D-05,-1.38336670D-07,1.
     361161375D-02,2.64450999D-05,2.45183218D-04,-3.10068552D-03,-3.2316
     49499D-06,-6.73294964D-07,2.64530330D-02,1.34315814D-01,1.86785955D
     5-03,3.63758045D-04,-2.51635077D-02,-3.81650783D-05,-4.52253373D-05
     6,2.22374038D-02,3.46442319D-05,3.20720242D-04,-4.19343166D-03,-3.9
     74496815D-06,-7.62346525D-07,3.24625000D-02,1.87419500D-01,2.600921
     876D-03,8.82270766D-04,-3.48515735D-02,-5.79381548D-05,-1.25315412D
     9-04,3.05671252D-02,4.99633104D-05,4.12341973D-04,-5.63157215D-03,-
     $4.65806978D-06,-5.21153772D-07,4.09781350D-02,2.60087239D-01/
      DATA (SC(I),I=3421,3465)/3.53449201D-03,1.69792856D-03,-4.77788269
     1D-02,-7.84395623D-05,-2.47244278D-04,4.18546618D-02,7.80766149D-05
     2,5.21228272D-04,-7.50973554D-03,-5.40289283D-06,3.31412596D-07,5.2
     38694780D-02,3.59215475D-01,4.70168455D-03,2.87226812D-03,-6.493410
     482D-02,-9.63740182D-05,-4.13172630D-04,5.70789490D-02,1.23694995D-
     504,6.45964272D-04,-9.93843451D-03,-5.97759826D-06,2.08185056D-06,6
     6.93175980D-02,4.93942284D-01,6.12761426D-03,4.45892931D-03,-8.7547
     70284D-02,-1.05812769D-04,-6.19225663D-04,7.74963026D-02,1.88594069
     8D-04,7.79965442D-04,-1.30371317D-02,-5.80216420D-06,4.97853671D-06
     9,9.18908940D-02,6.76210527D-01,7.81354980D-03,6.50501344D-03,-1.17
     $089309D-01,-9.61587583D-05,-8.52648448D-04,1.04672880D-01/
      DATA (SC(I),I=3466,3510)/2.70615016D-04,9.05970094D-04,-1.69156218
     1D-02,-3.54163140D-06,9.19226401D-06,1.22619080D-01,9.21345812D-01,
     29.70623589D-03,9.03821710D-03,-1.55216602D-01,-4.87137477D-05,-1.0
     38443952D-03,1.40471098D-01,3.61209490D-04,9.86715996D-04,-2.162551
     479D-02,3.08357965D-06,1.49882931D-05,1.64007720D-01,1.24848917D+00
     5,1.16393374D-02,1.20256234D-02,-2.03584976D-01,6.90811401D-05,-1.2
     65228907D-03,1.86923301D-01,4.42050634D-04,9.46385499D-04,-2.706795
     737D-02,1.83552470D-05,2.24703242D-05,2.18927400D-01,1.68053253D+00
     8,1.32292573D-02,1.52856381D-02,-2.63401073D-01,3.11964980D-04,-1.2
     93298327D-03,2.45872541D-01,4.75565038D-04,6.43534397D-04,-3.280306
     $86D-02,4.89287279D-05,3.16876210D-05,2.90235790D-01/
      DATA (SC(I),I=3511,3555)/2.24285857D+00,1.37114092D-02,1.83425182D
     1-02,-3.34476361D-01,7.63359536D-04,-8.07399414D-04,3.18156366D-01,
     23.96298791D-04,-1.61382433D-04,-3.77306881D-02,1.03277630D-04,4.18
     3032991D-05,3.79909150D-01,2.95968941D+00,1.17606930D-02,2.02514440
     4D-02,-4.13455755D-01,1.51744923D-03,3.36777983D-04,4.02024246D-01,
     51.13571386D-04,-1.78933384D-03,-3.96360614D-02,1.82682287D-04,4.92
     6816293D-05,4.87424740D-01,3.84645432D+00,5.55999826D-03,1.95859107
     7D-02,-4.91081493D-01,2.57057475D-03,2.42297147D-03,4.90593118D-01,
     8-4.30871068D-04,-4.41136088D-03,-3.49364425D-02,2.51773493D-04,4.2
     98253517D-05,6.07427800D-01,4.89760003D+00,-6.22388103D-03,1.504529
     $73D-02,-5.49786773D-01,3.55882532D-03,5.02394865D-03/
      DATA (SC(I),I=3556,3600)/5.69342560D-01,-1.11582335D-03,-7.3725184
     11D-03,-1.98414506D-02,2.00790123D-04,-1.26368325D-06,7.27917000D-0
     21,6.07452273D+00,-2.22179343D-02,6.87139891D-03,-5.66748804D-01,3.
     363237258D-03,6.54524066D-03,6.18077024D-01,-1.56090450D-03,-8.6215
     43482D-03,5.33421090D-03,-6.85221802D-05,-9.42306278D-05,8.32325190
     5D-01,7.30669267D+00,-3.71239988D-02,-2.33527347D-03,-5.28170928D-0
     61,2.18966637D-03,5.38963090D-03,6.22779698D-01,-1.42648812D-03,-6.
     728452968D-03,3.17582711D-02,-3.85184211D-04,-1.73416089D-04,9.0792
     80090D-01,8.51513370D+00,-4.49631483D-02,-9.16810137D-03,-4.4432801
     94D-01,-1.13034100D-04,2.24367414D-03,5.88904111D-01,-8.09971210D-0
     $4,-1.55461983D-03,4.76071546D-02,-4.38240918D-04,-1.54509016D-04/
      DATA (SC(I),I=3601,3645)/9.53727450D-01,9.64365443D+00,-4.40626195
     1D-02,-1.19730132D-02,-3.43069655D-01,-1.93730429D-03,-6.44895589D-
     204,5.36864846D-01,-1.43693532D-04,2.45514863D-03,4.95018782D-02,-2
     3.52175629D-04,-6.72095313D-05,9.77935570D-01,1.06721234D+01,-3.734
     492621D-02,-1.15022572D-02,-2.48914024D-01,-2.66787311D-03,-2.10186
     5398D-03,4.85243740D-01,2.61467141D-04,4.25820875D-03,4.25405098D-0
     62,-5.40769596D-05,8.17771079D-06,9.89726160D-01,1.16074371D+01,-2.
     787552971D-02,-9.44556679D-03,-1.73168173D-01,-2.56437484D-03,-2.36
     8985103D-03,4.42874723D-01,3.96514793D-04,4.33575622D-03,3.27732584
     9D-02,5.39983268D-05,4.36500535D-05,9.95250740D-01,1.24680301D+01,-
     $2.07975573D-02,-7.08482309D-03,-1.17136026D-01,-2.09357985D-03/
      DATA (SC(I),I=3646,3690)/-2.05732208D-03,4.11346440D-01,3.78342250
     1D-04,3.62198362D-03,2.36473510D-02,8.74798055D-05,5.02693123D-05,9
     2.97803290D-01,1.32735055D+01,-1.44406636D-02,-5.02834177D-03,-7.77
     3358704D-02,-1.56306428D-03,-1.58278267D-03,3.89145753D-01,3.044271
     410D-04,2.73491005D-03,1.63763169D-02,8.37366184D-05,4.37720469D-05
     5,9.98980120D-01,1.40403101D+01,-9.75785798D-03,-3.44528400D-03,-5.
     609070850D-02,-1.10628522D-03,-1.13906490D-03,3.74030236D-01,2.2447
     72310D-04,1.94789560D-03,1.10421720D-02,6.71656077D-05,3.37152561D-
     805,9.99524240D-01,1.47808281D+01,-6.47218821D-03,-2.30620875D-03,-
     93.30234311D-02,-7.56941653D-04,-7.87188631D-04,3.63959169D-01,1.57
     $532497D-04,1.33777416D-03,7.31126393D-03,4.94972138D-05/
      DATA (SC(I),I=3691,3735)/2.42937076D-05,9.99776990D-01,1.55038477D
     1+01,-4.23735121D-03,-1.51931866D-03,-2.12756483D-02,-5.06424601D-0
     24,-5.29963557D-04,3.57347904D-01,1.06970055D-04,8.97062831D-04,4.7
     38072362D-03,3.46552755D-05,1.68123291D-05,9.99894990D-01,1.6215384
     47D+01,-2.74848329D-03,-9.89769552D-04,-1.36377101D-02,-3.33701240D
     5-04,-3.50544342D-04,3.53051686D-01,7.12039562D-05,5.91805096D-04,3
     6.09770100D-03,2.35597998D-05,1.13342761D-05,9.99950340D-01,1.69194
     7626D+01,-1.77070885D-03,-6.39627090D-04,-8.70929621D-03,-2.1738325
     88D-04,-2.29035266D-04,3.50280586D-01,4.67252325D-05,3.85969344D-04
     9,1.99345541D-03,1.57589180D-05,7.50599734D-06,9.99976430D-01,1.761
     $87300D+01,-1.13507961D-03,-4.10941987D-04,-5.54639128D-03/
      DATA (SC(I),I=3736,3780)/-1.40440247D-04,-1.48334236D-04,3.4850283
     19D-01,3.03410194D-05,2.49659897D-04,1.27752709D-03,1.02945828D-05,
     24.91200711D-06,9.99988780D-01,1.83149115D+01,-7.24911539D-04,-2.62
     3861802D-04,-3.52466118D-03,-9.01939568D-05,-9.54474319D-05,3.47366
     4563D-01,1.96708238D-05,1.60508170D-04,8.15071084D-04,6.73578325D-0
     56,3.18077205D-06,9.99994630D-01,1.05258314D-02,1.17950698D-04,-4.2
     65321202D-05,-1.94620206D-03,2.16789486D-06,6.68831998D-06,1.996776
     745D-03,3.50489164D-06,3.46178414D-05,-4.18656203D-04,-1.87254326D-
     807,-8.74028936D-08,7.37472670D-03,1.54625264D-02,2.05731459D-04,-5
     9.85233551D-05,-2.97468042D-03,-1.94686364D-07,1.14053038D-05,2.826
     $85476D-03,5.78690262D-06,5.31629193D-05,-5.98477560D-04/
      DATA (SC(I),I=3781,3825)/-6.67387912D-07,-2.39245482D-07,7.7357954
     10D-03,2.24254934D-02,3.35557071D-04,-7.04832262D-05,-4.42665902D-0
     23,-5.23859384D-06,1.53781822D-05,3.98017862D-03,8.36124447D-06,7.6
     36626926D-05,-8.41247393D-04,-1.20297148D-06,-4.12348864D-07,8.4934
     46210D-03,3.21883404D-02,5.18912901D-04,-6.84175504D-05,-6.44758944
     5D-03,-1.32850789D-05,1.66781348D-05,5.58189888D-03,1.11180949D-05,
     61.06693137D-04,-1.17022299D-03,-1.77835107D-06,-6.29571129D-07,9.7
     76357590D-03,4.58147308D-02,7.71000471D-04,-3.31595188D-05,-9.23368
     8300D-03,-2.46361955D-05,1.17859712D-05,7.80250535D-03,1.40385291D-
     905,1.45394433D-04,-1.61623218D-03,-2.37641361D-06,-8.91222494D-07,
     $1.16953760D-02,6.47627386D-02,1.11174622D-03,6.71104676D-05/
      DATA (SC(I),I=3826,3870)/-1.30477834D-02,-3.96617851D-05,-4.915271
     175D-06,1.08733346D-02,1.76534837D-05,1.95351319D-04,-2.21920783D-0
     23,-3.04128340D-06,-1.20387527D-06,1.45005540D-02,9.10292651D-02,1.
     356664119D-03,2.77478912D-04,-1.82410504D-02,-5.87647150D-05,-4.105
     437954D-05,1.51073609D-02,2.36510434D-05,2.59543650D-04,-3.03118205
     5D-03,-3.81013944D-06,-1.49616685D-06,1.84856000D-02,1.27348253D-01
     6,2.16745105D-03,6.52005460D-04,-2.52827240D-02,-8.22164676D-05,-1.
     704949894D-04,2.09263365D-02,3.53563198D-05,3.41266209D-04,-4.11871
     8938D-03,-4.79307464D-06,-1.62649536D-06,2.40867670D-02,1.77454064D
     9-01,2.95260393D-03,1.24678731D-03,-3.47966599D-02,-1.09996126D-04,
     $-2.03896973D-04,2.88965204D-02,5.72262951D-05,4.43886670D-04/
      DATA (SC(I),I=3871,3915)/-5.56652222D-03,-6.08055684D-06,-1.389702
     135D-06,3.19105840D-02,2.46419682D-01,3.96672184D-03,2.11619850D-03
     2,-4.76028209D-02,-1.41382627D-04,-3.42896985D-04,3.97737381D-02,9.
     334268887D-05,5.70231241D-04,-7.48037851D-03,-7.64879797D-06,-5.741
     493477D-07,4.27924590D-02,3.41081116D-01,5.25822498D-03,3.31541401D
     5-03,-6.47599710D-02,-1.74229773D-04,-5.24289633D-04,5.45554065D-02
     6,1.46574698D-04,7.21271900D-04,-9.98808609D-03,-9.21478286D-06,1.0
     71420148D-06,5.78679860D-02,4.70558357D-01,6.87313807D-03,4.9052669
     85D-03,-8.76032943D-02,-2.04072137D-04,-7.47098044D-04,7.45326629D-
     902,2.17537173D-04,8.93641190D-04,-1.32333084D-02,-1.02628133D-05,3
     $.54221270D-06,7.86473510D-02,6.46870308D-01,8.84063587D-03/
      DATA (SC(I),I=3916,3960)/6.95042835D-03,-1.17766408D-01,-2.2159073
     16D-04,-1.00334924D-03,1.01335323D-01,3.04091671D-04,1.07385661D-03
     2,-1.73617803D-02,-9.34644749D-06,7.30774837D-06,1.07082440D-01,8.8
     35588587D-01,1.11435289D-02,9.50332892D-03,-1.57149015D-01,-2.09183
     4789D-04,-1.27000542D-03,1.36928893D-01,3.99978927D-04,1.22903645D-
     503,-2.24733035D-02,-4.33930184D-06,1.25814745D-05,1.45592310D-01,1
     6.20638706D+00,1.36599652D-02,1.25611930D-02,-2.07766921D-01,-1.342
     785059D-04,-1.49146179D-03,1.83522268D-01,4.88762143D-04,1.28739979
     8D-03,-2.85373316D-02,9.28231912D-06,1.99248735D-05,1.96979410D-01,
     91.63315644D+00,1.60559503D-02,1.59835635D-02,-2.71346833D-01,6.119
     $41016D-05,-1.55155535D-03,2.43247896D-01,5.36833709D-04/
      DATA (SC(I),I=3961,4005)/1.10858535D-03,-3.52070138D-02,3.86627577
     1D-05,2.98696298D-05,2.64113260D-01,2.19304033D+00,1.76082114D-02,1
     2.93525365D-02,-3.48436195D-01,4.71841137D-04,-1.23568548D-03,3.174
     333253D-01,4.82620750D-04,4.43675767D-04,-4.15030629D-02,9.39575774
     4D-05,4.28335527D-05,3.49191510D-01,2.91326793D+00,1.69774190D-02,2
     5.17930219D-02,-4.36689097D-01,1.22394197D-03,-2.15860255D-04,4.051
     647380D-01,2.35631833D-04,-1.07446823D-03,-4.53367815D-02,1.8178129
     79D-04,5.74779900D-05,4.52356120D-01,3.81418718D+00,1.21354855D-02,
     82.18939340D-02,-5.28066981D-01,2.39280476D-03,1.82468806D-03,5.007
     961722D-01,-2.82641803D-04,-3.76746526D-03,-4.30993227D-02,2.798545
     $35D-04,6.53175687D-05,5.69634780D-01,4.89739814D+00/
      DATA (SC(I),I=4006,4050)/1.06338129D-03,1.81274567D-02,-6.05728391
     1D-01,3.74548211D-03,4.71081710D-03,5.91048381D-01,-1.01087827D-03,
     2-7.30463892D-03,-3.02876031D-02,2.90235618D-04,4.09309519D-05,6.91
     3018060D-01,6.13184113D+00,-1.60862128D-02,1.01344555D-02,-6.447516
     489D-01,4.44946733D-03,7.08009807D-03,6.55179320D-01,-1.61723514D-0
     53,-9.84495513D-03,-5.08737663D-03,6.86103266D-05,-4.77842832D-05,8
     6.01213870D-01,7.44920926D+00,-3.47240690D-02,-2.52133424D-05,-6.23
     7904489D-01,3.51728610D-03,6.89921389D-03,6.73966891D-01,-1.6826638
     85D-03,-8.79290112D-03,2.58964027D-02,-3.19765537D-04,-1.67151121D-
     904,8.85971720D-01,8.76192429D+00,-4.75918830D-02,-8.69825778D-03,-
     $5.44630970D-01,1.10376819D-03,3.91965098D-03,6.45769759D-01/
      DATA (SC(I),I=4051,4095)/-1.14418337D-03,-4.07491290D-03,4.9191102
     18D-02,-5.17560559D-04,-2.02281740D-04,9.40631800D-01,9.99711187D+0
     20,-5.05388387D-02,-1.32708301D-02,-4.33493871D-01,-1.35676137D-03,
     33.33291066D-04,5.89317906D-01,-3.81520513D-04,1.12795729D-03,5.682
     447041D-02,-3.84830819D-04,-1.25591662D-04,9.71009530D-01,1.1119605
     54D+01,-4.52290443D-02,-1.37453949D-02,-3.21554704D-01,-2.71834132D
     6-03,-1.92997713D-03,5.27590731D-01,1.82094806D-04,4.18183704D-03,5
     7.18703144D-02,-1.43962879D-04,-2.64046126D-05,9.86309410D-01,1.212
     892803D+01,-3.61038190D-02,-1.18062160D-02,-2.27154652D-01,-2.95045
     9617D-03,-2.66407079D-03,4.74289028D-01,4.26945228D-04,4.94338828D-
     $03,4.14457474D-02,2.07005309D-05,3.36095350D-05,9.93622090D-01/
      DATA (SC(I),I=4096,4140)/1.30445818D+01,-2.67452281D-02,-9.1090238
     15D-03,-1.55289745D-01,-2.55895606D-03,-2.49789941D-03,4.33471325D-
     201,4.52769646D-04,4.41520260D-03,3.06003833D-02,8.78233435D-05,5.3
     36166467D-05,9.97038470D-01,1.38884656D+01,-1.88711930D-02,-6.58461
     4608D-03,-1.03827004D-01,-1.97821123D-03,-2.00026718D-03,4.04227734
     5D-01,3.82350716D-04,3.45883251D-03,2.15131968D-02,9.72106374D-05,5
     6.17217862D-05,9.98622900D-01,1.46814178D+01,-1.28930991D-02,-4.567
     745602D-03,-6.83589037D-02,-1.43072900D-03,-1.47405864D-03,3.840911
     820D-01,2.90106880D-04,2.51926137D-03,1.46540191D-02,8.29461874D-05
     9,4.18625022D-05,9.99357560D-01,1.54393704D+01,-8.61835531D-03,-3.0
     $8352192D-03,-4.45191394D-02,-9.92881129D-04,-1.03423971D-03/
      DATA (SC(I),I=4141,4185)/3.70573772D-01,2.06763164D-04,1.75548246D
     1-03,9.77307786D-03,6.30844281D-05,3.10308201D-05,9.99699140D-01,1.
     261738480D+01,-5.67403832D-03,-2.04373678D-03,-2.87663064D-02,-6.70
     3597844D-04,-7.03422884D-04,3.61650309D-01,1.42271998D-04,1.1888345
     44D-03,6.42241277D-03,4.51674460D-05,2.18589486D-05,9.99858570D-01,
     51.68928377D+01,-3.69545091D-03,-1.33726996D-03,-1.84806168D-02,-4.
     644668012D-04,-4.68607606D-04,3.55829532D-01,9.54621475D-05,7.89752
     7868D-04,4.17786485D-03,3.10270290D-05,1.49114921D-05,9.99933270D-0
     81,1.76017273D+01,-2.38804669D-03,-8.67017164D-04,-1.18215766D-02,-
     92.91191543D-04,-3.07740940D-04,3.52064576D-01,6.28717072D-05,5.176
     $51350D-04,2.69704380D-03,2.08412409D-05,9.95847267D-06/
      DATA (SC(I),I=4186,4230)/9.99968410D-01,1.83040839D+01,-1.53432665
     1D-03,-5.58368340D-04,-7.53769964D-03,-1.88932144D-04,-2.00059107D-
     204,3.49642863D-01,4.12495910D-05,3.36068691D-04,1.73133910D-03,1.3
     37821791D-05,6.54780673D-06,9.99984990D-01,1.90022409D+01,-9.815864
     456D-04,-3.57843622D-04,-4.79453015D-03,-1.21770288D-04,-1.29099783
     5D-04,3.48094172D-01,2.64844983D-05,2.16671502D-04,1.10707743D-03,8
     6.98451407D-06,4.26642816D-06,9.99992860D-01,7.13117721D-03,1.16868
     7117D-04,-2.96270763D-05,-1.46235270D-03,-2.25495258D-06,6.21672383
     8D-06,1.29830731D-03,2.82025951D-06,2.83841895D-05,-2.89760912D-04,
     9-4.53537571D-07,-2.11072941D-07,3.14597310D-03,1.03526922D-02,1.86
     $063216D-04,-3.84775699D-05,-2.16893689D-03,-5.73619833D-06/
      DATA (SC(I),I=4231,4275)/8.64048135D-06,1.83826297D-03,4.07888187D
     1-06,4.08109103D-05,-4.09434624D-04,-7.50940153D-07,-3.25072207D-07
     2,3.51000590D-03,1.48995362D-02,2.84063951D-04,-4.45421460D-05,-3.1
     36048956D-03,-1.10042096D-05,1.05628979D-05,2.59486943D-03,5.567395
     411D-06,5.71898240D-05,-5.74375787D-04,-1.08214766D-06,-4.75845601D
     5-07,4.09626340D-03,2.12933378D-02,4.20307666D-04,-4.11169243D-05,-
     64.54160484D-03,-1.84291373D-05,1.06224913D-05,3.65334385D-03,7.202
     736363D-06,7.90538913D-05,-8.01225609D-04,-1.48177815D-06,-6.726924
     854D-07,4.97289590D-03,3.02553684D-02,6.07492860D-04,-1.50553059D-0
     95,-6.45414774D-03,-2.85072398D-05,6.31824162D-06,5.13131174D-03,9.
     $04915260D-06,1.08131303D-04,-1.11285981D-03,-1.94703890D-06/
      DATA (SC(I),I=4276,4320)/-9.37541754D-07,6.23861720D-03,4.27816892
     1D-02,8.62392664D-04,5.56388725D-05,-9.08962471D-03,-4.18613984D-05
     2,-6.55632326D-06,7.19027100D-03,1.14832479D-05,1.46768501D-04,-1.5
     33938473D-03,-2.52010420D-06,-1.27239444D-06,8.03778010D-03,6.02480
     4467D-02,1.20692286D-03,2.02659414D-04,-1.27070568D-02,-5.92452891D
     5-05,-3.37657024D-05,1.00513097D-02,1.57839001D-05,1.97761694D-04,-
     62.12095189D-03,-3.25952289D-06,-1.63992383D-06,1.05766180D-02,8.45
     7556891D-02,1.66926943D-03,4.65055205D-04,-1.76573668D-02,-8.148824
     818D-05,-8.20003610D-05,1.40162212D-02,2.43768503D-05,2.64584872D-0
     94,-2.91040979D-03,-4.27259255D-06,-1.94943705D-06,1.41458790D-02,1
     $.18328600D-01,2.28515913D-03,8.85164020D-04,-2.44152119D-02/
      DATA (SC(I),I=4321,4365)/-1.09417193D-04,-1.57726314D-04,1.9495912
     15D-02,4.06195517D-05,3.51304832D-04,-3.97706584D-03,-5.67748152D-0
     26,-2.06496431D-06,1.91541780D-02,1.65172910D-01,3.09895171D-03,1.5
     30676813D-03,-3.36171879D-02,-1.43720333D-04,-2.66533389D-04,2.7047
     47474D-02,6.78421349D-05,4.62487744D-04,-5.41062276D-03,-7.56344836
     5D-06,-1.84567592D-06,2.61706310D-02,2.30012569D-01,4.16412339D-03,
     62.37794287D-03,-4.61063756D-02,-1.84601397D-04,-4.13181506D-04,3.7
     74213283D-02,1.08743780D-04,6.02683947D-04,-7.32563029D-03,-9.85894
     8124D-06,-1.17246651D-06,3.59783070D-02,3.19519941D-01,5.54217697D-
     903,3.55638467D-03,-6.29819394D-02,-2.31189598D-04,-6.01784236D-04,
     $5.16126298D-02,1.65058412D-04,7.75369626D-04,-9.86268988D-03/
      DATA (SC(I),I=4366,4410)/-1.23485237D-05,8.58309228D-08,4.96393820
     1D-02,4.42656376D-01,7.29792113D-03,5.11245516D-03,-8.56502533D-02,
     2-2.80421239D-04,-8.34623954D-04,7.09214005D-02,2.37672946D-04,9.80
     3374533D-04,-1.31865218D-02,-1.44541472D-05,2.10101968D-06,6.856740
     460D-02,6.11319838D-01,9.48720752D-03,7.12496194D-03,-1.15863566D-0
     51,-3.24938584D-04,-1.10836155D-03,9.70018387D-02,3.25770044D-04,1.
     620891186D-03,-1.74712895D-02,-1.50446053D-05,5.13906004D-06,9.4593
     75510D-02,8.41055344D-01,1.21298082D-02,9.66419785D-03,-1.55714467D
     8-01,-3.49206721D-04,-1.40553341D-03,1.31880098D-01,4.24434208D-04,
     91.43368878D-03,-2.28636252D-02,-1.18749682D-05,9.64644499D-06,1.29
     $997590D-01,1.15169872D+00,1.51541868D-02,1.27534533D-02/
      DATA (SC(I),I=4411,4455)/-2.07521114D-01,-3.22621320D-04,-1.678554
     181D-03,1.77883432D-01,5.20282936D-04,1.59068982D-03,-2.93992368D-0
     22,-7.73645304D-07,1.62948691D-05,1.77446730D-01,1.56766484D+00,1.8
     32930297D-02,1.62942817D-02,-2.73479881D-01,-1.88180184D-04,-1.8225
     46936D-03,2.37380578D-01,5.83815687D-04,1.54815316D-03,-3.68371820D
     5-02,2.55863941D-05,2.61129502D-05,2.39742540D-01,2.11730724D+00,2.
     609043865D-02,1.99395724D-02,-3.54867582D-01,1.52459904D-04,-1.6375
     78921D-03,3.12152255D-01,5.59688248D-04,1.06320356D-03,-4.43587140D
     8-02,7.81727991D-05,4.04479006D-05,3.19222240D-01,2.83033541D+00,2.
     917193757D-02,2.29179671D-02,-4.50462531D-01,8.44790891D-04,-8.0065
     $4997D-04,4.02117880D-01,3.61749060D-04,-2.48214356D-04/
      DATA (SC(I),I=4456,4500)/-5.00989082D-02,1.67601629D-04,5.99431644
     1D-05,4.16629480D-01,3.73177586D+00,1.86537678D-02,2.39034928D-02,-
     25.53854294D-01,2.02928123D-03,1.06521904D-03,5.03113803D-01,-1.018
     341333D-04,-2.81739347D-03,-5.06394104D-02,2.84957088D-04,7.9743286
     45D-05,5.29378090D-01,4.83103235D+00,9.19125770D-03,2.12409377D-02,
     5-6.49960468D-01,3.62489977D-03,4.02638409D-03,6.03874251D-01,-8.29
     6768183D-04,-6.64511667D-03,-4.11497194D-02,3.55223882D-04,7.788501
     728D-05,6.49663500D-01,6.10718553D+00,-7.80259741D-03,1.39810700D-0
     82,-7.13671171D-01,4.94983218D-03,7.10706946D-03,6.84414906D-01,-1.
     957222911D-03,-1.03487384D-02,-1.79437727D-02,2.18594546D-04,1.0762
     $7630D-05,7.64146110D-01,7.49912285D+00,-2.91946491D-02/
      DATA (SC(I),I=4501,4545)/3.38082350D-03,-7.17747984D-01,4.79189856
     1D-03,8.15943030D-03,7.21765234D-01,-1.87878268D-03,-1.10433132D-02
     2,1.56216374D-02,-1.80172477D-04,-1.28151640D-04,8.57997220D-01,8.9
     31549192D+00,-4.73964936D-02,-7.04337188D-03,-6.52503366D-01,2.6489
     43139D-03,5.89416713D-03,7.05770993D-01,-1.51073044D-03,-7.15853126
     5D-03,4.65216632D-02,-5.34262639D-04,-2.28896830D-04,9.22898750D-01
     6,1.02672406D+01,-5.56548510D-02,-1.38036349D-02,-5.38148550D-01,-3
     7.10799167D-04,1.87173719D-03,6.49704126D-01,-7.17599084D-04,-1.099
     882617D-03,6.21223612D-02,-5.24497243D-04,-1.92208565D-04,9.6121191
     90D-01,1.14998273D+01,-5.32818701D-02,-1.58126429D-02,-4.10068892D-
     $01,-2.45064533D-03,-1.34235612D-03,5.79204544D-01,1.35922154D-05/
      DATA (SC(I),I=4546,4590)/3.47280705D-03,6.13792119D-02,-2.73492387
     1D-04,-7.97248852D-05,9.81342270D-01,1.26007781D+01,-4.44956861D-02
     2,-1.43952171D-02,-2.95194917D-01,-3.22424529D-03,-2.78829380D-03,5
     3.13951424D-01,4.12572296D-04,5.31337700D-03,5.14164702D-02,-4.3944
     40406D-05,1.03613313D-05,9.91215260D-01,1.35853368D+01,-3.39612111D
     5-02,-1.15150622D-02,-2.04441402D-01,-3.04174032D-03,-2.93017892D-0
     63,4.62022383D-01,5.17920716D-04,5.22109803D-03,3.90876716D-02,7.35
     7656717D-05,5.12695226D-05,9.95896400D-01,1.44788318D+01,-2.4444046
     89D-02,-8.51900129D-03,-1.37934402D-01,-2.46137506D-03,-2.47748663D
     9-03,4.23964800D-01,4.68817880D-04,4.29606613D-03,2.80032019D-02,1.
     $06809627D-04,5.85378120D-05,9.98085530D-01,1.53060177D+01/
      DATA (SC(I),I=4591,4635)/-1.69275932D-02,-6.00058946D-03,-9.140301
     147D-02,-1.82982963D-03,-1.88282783D-03,3.97385781D-01,3.68443615D-
     204,3.22038760D-03,1.93169703D-02,9.96059458D-05,5.08193284D-05,9.9
     39105350D-01,1.60870102D+01,-1.14219884D-02,-4.09369905D-03,-5.9806
     44217D-02,-1.29249955D-03,-1.34653938D-03,3.79370626D-01,2.68939453
     5D-04,2.28521720D-03,1.29958375D-02,7.91324970D-05,3.91072669D-05,9
     6.99580750D-01,1.68367297D+01,-7.57033040D-03,-2.73331555D-03,-3.87
     7781747D-02,-8.83449320D-04,-9.27437982D-04,3.67401062D-01,1.875561
     846D-04,1.56644080D-03,8.59345796D-03,5.81084075D-05,2.81769453D-05
     9,9.99802910D-01,1.75656820D+01,-4.95452286D-03,-1.79797661D-03,-2.
     $49774269D-02,-5.90636091D-04,-6.23218505D-04,3.59556406D-01/
      DATA (SC(I),I=4636,4680)/1.26860226D-04,1.04936675D-03,5.61491812D
     1-03,4.06163767D-05,1.95048853D-05,9.99907060D-01,1.82810264D+01,-3
     2.21319051D-03,-1.17023698D-03,-1.60088066D-02,-3.89074299D-04,-4.1
     31809531D-04,3.54463149D-01,8.44200815D-05,6.91965605D-04,3.6374737
     43D-03,2.75052533D-05,1.31543804D-05,9.99956040D-01,1.89875386D+01,
     5-2.07003002D-03,-7.55847079D-04,-1.02229309D-02,-2.53511765D-04,-2
     6.68903675D-04,3.51180573D-01,5.52869825D-05,4.51194880D-04,2.34023
     7803D-03,1.84023947D-05,8.71923851D-06,9.99979160D-01,1.96883582D+0
     81,-1.32697839D-03,-4.85450172D-04,-6.51019400D-03,-1.63819474D-04,
     9-1.74118260D-04,3.49075093D-01,3.59436401D-05,2.91856748D-04,1.499
     $69434D-03,1.20111316D-05,5.71338090D-06,9.99990100D-01/
      DATA (SC(I),I=4681,4725)/2.03855272D+01,-8.47483224D-04,-3.1047442
     18D-04,-4.13687776D-03,-1.05330987D-04,-1.12020624D-04,3.47730326D-
     201,2.31469860D-05,1.87638422D-04,9.57191834D-04,7.81163309D-06,3.7
     30809790D-06,9.99995300D-01,4.66736482D-03,9.67432998D-05,-1.900969
     447D-05,-1.02578912D-03,-4.15782377D-06,4.40065777D-06,8.28545109D-
     504,1.90517111D-06,2.04867472D-05,-1.92342380D-04,-4.20238997D-07,-
     62.05159426D-07,1.40446260D-03,6.73067020D-03,1.46106544D-04,-2.409
     709421D-05,-1.49452972D-03,-7.16252600D-06,5.74614638D-06,1.1757733
     87D-03,2.63723480D-06,2.88764966D-05,-2.71680979D-04,-5.85954140D-0
     97,-2.90998549D-07,1.66734260D-03,9.64986600D-03,2.15327252D-04,-2.
     $72626800D-05,-2.15277535D-03,-1.14172566D-05,6.71656809D-06/
      DATA (SC(I),I=4726,4770)/1.66487055D-03,3.52219912D-06,4.03442122D
     1-05,-3.81782004D-04,-8.33354280D-07,-4.17058349D-07,2.05430650D-03
     2,1.37688999D-02,3.11546066D-04,-2.40473185D-05,-3.07293564D-03,-1.
     372994675D-05,6.44711450D-06,2.35308704D-03,4.55063302D-06,5.587460
     418D-05,-5.35113944D-04,-1.10373621D-06,-5.86956597D-07,2.61013600D
     5-03,1.95663903D-02,4.44439067D-04,-5.66087366D-06,-4.35349632D-03,
     6-2.52750628D-05,3.07619067D-06,3.31963447D-03,5.71172856D-06,7.701
     783989D-05,-7.47254701D-04,-1.47815985D-06,-8.18944975D-07,3.400251
     890D-03,2.77077790D-02,6.26989287D-04,4.27791831D-05,-6.12897619D-0
     93,-3.59915730D-05,-6.30336616D-06,4.67458022D-03,7.35214095D-06,1.
     $05531821D-04,-1.04061251D-03,-1.93949700D-06,-1.12165329D-06/
      DATA (SC(I),I=4771,4815)/4.51826600D-03,3.91192028D-02,8.76404254D
     1-04,1.42955658D-04,-8.58313809D-03,-5.02185521D-05,-2.59380536D-05
     2,6.56990559D-03,1.03473652D-05,1.43883146D-04,-1.44447073D-03,-2.5
     37550384D-06,-1.47683542D-06,6.09759280D-03,5.50909143D-02,1.215411
     470D-03,3.22204293D-04,-1.19680055D-02,-6.89211188D-05,-6.08505509D
     5-05,9.21525423D-03,1.64454271D-05,1.95124299D-04,-1.99869300D-03,-
     63.47075010D-06,-1.82819399D-06,8.32792640D-03,7.74191971D-02,1.673
     767276D-03,6.11169087D-04,-1.66290403D-02,-9.32249296D-05,-1.162686
     819D-04,1.28992197D-02,2.80672746D-05,2.63136762D-04,-2.75633654D-0
     93,-4.75829131D-06,-2.09467000D-06,1.14771720D-02,1.08596367D-01,2.
     $28948511D-03,1.04299017D-03,-2.30369590D-02,-1.24364643D-04/
      DATA (SC(I),I=4816,4860)/-1.97244571D-04,1.80181645D-02,4.77270619
     1D-05,3.52675590D-04,-3.78824060D-03,-6.52832959D-06,-2.18856554D-0
     26,1.59210310D-02,1.52061909D-01,3.11149144D-03,1.65586448D-03,-3.1
     38265947D-02,-1.63641563D-04,-3.08896887D-04,2.51127980D-02,7.77205
     4472D-05,4.69330739D-04,-5.18696823D-03,-8.87335328D-06,-2.04821164
     5D-06,2.21819970D-02,2.12533573D-01,4.20000264D-03,2.49774195D-03,-
     64.38446556D-02,-2.12114994D-04,-4.56858477D-04,3.49145414D-02,1.19
     7970215D-04,6.19180458D-04,-7.07256026D-03,-1.17124473D-05,-1.60270
     8348D-06,3.09791820D-02,2.96438606D-01,5.62712034D-03,3.63058086D-0
     93,-6.02059420D-02,-2.70079772D-04,-6.47250345D-04,4.84000011D-02,1
     $.76241898D-04,8.07937246D-04,-9.59434351D-03,-1.49137975D-05/
      DATA (SC(I),I=4861,4905)/-7.53440581D-07,4.32884930D-02,4.12460596
     1D-01,7.47367457D-03,5.13142690D-03,-8.23546065D-02,-3.36128994D-04
     2,-8.85173495D-04,6.68519794D-02,2.48059109D-04,1.03861698D-03,-1.2
     39315746D-02,-1.80145875D-05,6.57214417D-07,6.04093700D-02,5.722026
     475D-01,9.81924245D-03,7.08768051D-03,-1.12118025D-01,-4.05019862D-
     504,-1.17098393D-03,9.19171407D-02,3.35585021D-04,1.30695090D-03,-1
     6.72823044D-02,-1.99956207D-05,2.90755969D-06,8.40272880D-02,7.9093
     71967D-01,1.27185000D-02,9.58227525D-03,-1.51723548D-01,-4.63973295
     8D-04,-1.49262327D-03,1.25636438D-01,4.35466248D-04,1.59230667D-03,
     9-2.28311513D-02,-1.88642424D-05,6.47558727D-06,1.16248280D-01,1.08
     $829770D+00,1.61510881D-02,1.26606895D-02,-2.03721497D-01/
      DATA (SC(I),I=4906,4950)/-4.85927343D-04,-1.81102278D-03,1.7040252
     15D-01,5.37131847D-04,1.84028141D-03,-2.96777207D-02,-1.07018665D-0
     25,1.21134975D-05,1.59560140D-01,1.48877868D+00,1.99247488D-02,1.62
     3663231D-02,-2.70701850D-01,-4.17979881D-04,-2.03566007D-03,2.28757
     4629D-01,6.15662376D-04,1.93337924D-03,-3.76875107D-02,1.14121328D-
     505,2.11499673D-05,2.16642270D-01,2.02136780D+00,2.35047268D-02,2.0
     61291494D-02,-3.54611080D-01,-1.64619201D-04,-1.98816270D-03,3.0287
     75562D-01,6.23115720D-04,1.64659875D-03,-4.62232828D-02,5.85715524D
     8-05,3.55466876D-05,2.89904240D-01,2.71761271D+00,2.57561067D-02,2.
     936016854D-02,-4.55359890D-01,4.25893229D-04,-1.36702647D-03,3.9348
     $6103D-01,4.81285046D-04,6.04781170D-04,-5.37043184D-02/
      DATA (SC(I),I=4951,4995)/1.43743681D-04,5.73942936D-05,3.80601700D
     1-01,3.60663845D+00,2.46779622D-02,2.54962100D-02,-5.68364184D-01,1
     2.53728218D-03,2.28888226D-04,4.97938745D-01,9.22812262D-05,-1.6829
     32562D-03,-5.70610808D-02,2.69121167D-04,8.54353319D-05,4.87423170D
     4-01,4.70554609D+00,1.75013722D-02,2.41447578D-02,-6.81005106D-01,3
     5.22729447D-03,3.05661830D-03,6.07293165D-01,-5.91411373D-04,-5.493
     666438D-03,-5.15125418D-02,3.86513367D-04,1.03936282D-04,6.04742610
     7D-01,6.00499826D+00,1.98798721D-03,1.81230797D-02,-7.69775988D-01,
     85.04786168D-03,6.58282585D-03,7.03661158D-01,-1.41904165D-03,-1.00
     9197206D-02,-3.20722383D-02,3.50862652D-04,6.89713031D-05,7.2158880
     $0D-01,7.45545667D+00,-2.06319755D-02,7.74985515D-03/
      DATA (SC(I),I=4996,5040)/-8.04002632D-01,5.79311227D-03,8.89905990
     1D-03,7.62434629D-01,-1.97159505D-03,-1.26002421D-02,1.39968789D-03
     2,1.38624217D-05,-6.10710827D-05,8.23626570D-01,8.96811828D+00,-4.3
     36438814D-02,-4.03807216D-03,-7.62765069D-01,4.34749338D-03,7.89382
     4552D-03,7.65281912D-01,-1.85935919D-03,-1.04116638D-02,3.85979554D
     5-02,-4.57096079D-04,-2.18504704D-04,8.99588350D-01,1.04413042D+01,
     6-5.83025843D-02,-1.31968707D-02,-6.54864619D-01,1.22463777D-03,3.9
     75812828D-03,7.16400127D-01,-1.13682387D-03,-4.24703905D-03,6.37618
     8939D-02,-6.33633784D-04,-2.52193241D-04,9.47631250D-01,1.17985816D
     9+01,-6.06849482D-02,-1.73641145D-02,-5.15274538D-01,-1.72325455D-0
     $3,-1.80603634D-04,6.40496725D-01,-2.67575581D-04,1.86467514D-03/
      DATA (SC(I),I=5041,5085)/6.99557193D-02,-4.36943852D-04,-1.5117528
     15D-04,9.74215330D-01,1.30091296D+01,-5.36066426D-02,-1.70419947D-0
     22,-3.79579149D-01,-3.26334396D-03,-2.59675357D-03,5.63238087D-01,3
     3.24652285D-04,5.21363046D-03,6.23041398D-02,-1.50427964D-04,-3.149
     476000D-05,9.87690430D-01,1.40801234D+01,-4.24696451D-02,-1.4275050
     50D-02,-2.67101309D-01,-3.48081703D-03,-3.27856203D-03,4.98504390D-
     601,5.56626216D-04,5.92336705D-03,4.91726965D-02,3.44106906D-05,3.8
     77783375D-05,9.94203350D-01,1.50371120D+01,-3.13327749D-02,-1.08744
     8732D-02,-1.82207815D-01,-2.99632274D-03,-2.99105590D-03,4.49634936
     9D-01,5.56307702D-04,5.21350309D-03,3.60727411D-02,1.07101773D-04,6
     $.19563464D-05,9.97282680D-01,1.59088444D+01,-2.20614743D-02/
      DATA (SC(I),I=5086,5130)/-7.80766906D-03,-1.21684051D-01,-2.308337
     127D-03,-2.36743063D-03,4.14876932D-01,4.59723331D-04,4.05779750D-0
     23,2.52749967D-02,1.15150660D-04,5.97839517D-05,9.98726430D-01,1.67
     3201583D+01,-1.50571383D-02,-5.39564617D-03,-8.00670467D-02,-1.6671
     46806D-03,-1.73489264D-03,3.91039891D-01,3.45032485D-04,2.94653849D
     5-03,1.71863582D-02,9.72283512D-05,4.84216436D-05,9.99402080D-01,1.
     674900978D+01,-1.00603090D-02,-3.63499324D-03,-5.21284358D-02,-1.15
     7646795D-03,-1.21379812D-03,3.75073629D-01,2.44789185D-04,2.0502908
     84D-03,1.14501174D-02,7.37765226D-05,3.59235348D-05,9.99718600D-01,
     91.82323415D+01,-6.62239778D-03,-2.40638513D-03,-3.36790352D-02,-7.
     $81037585D-04,-8.24338616D-04,3.64548179D-01,1.67829997D-04/
      DATA (SC(I),I=5131,5175)/1.38762038D-03,7.52132697D-03,5.26846059D
     1-05,2.53305213D-05,9.99867220D-01,1.89563334D+01,-4.31318757D-03,-
     21.57349247D-03,-2.16362872D-02,-5.17979360D-04,-5.48741716D-04,3.5
     37687033D-01,1.12536887D-04,9.21589824D-04,4.89111055D-03,3.6227890
     47D-05,1.72860947D-05,9.99937170D-01,1.96684306D+01,-2.78749541D-03
     5,-1.01983881D-03,-1.38404160D-02,-3.39293277D-04,-3.60270382D-04,3
     6.53251632D-01,7.39129905D-05,6.04102339D-04,3.15796005D-03,2.42579
     7903D-05,1.15710657D-05,9.99970210D-01,2.03728371D+01,-1.79117978D-
     803,-6.56650393D-04,-8.82519532D-03,-2.20243996D-04,-2.34155341D-04
     9,3.50399520D-01,4.83031396D-05,3.92213285D-04,2.02682468D-03,1.608
     $50632D-05,7.61052156D-06,9.99985800D-01,2.10723000D+01/
      DATA (SC(I),I=5176,5220)/-1.14599839D-03,-4.20759676D-04,-5.613334
     128D-03,-1.42115317D-04,-1.51150201D-04,3.48574590D-01,3.12240814D-
     205,2.52968107D-04,1.29671070D-03,1.04078595D-05,4.96089507D-06,9.9
     39993230D-01,2.17685998D+01,-7.30902995D-04,-2.68662616D-04,-3.5642
     41506D-03,-9.12091839D-05,-9.69128799D-05,3.47410893D-01,2.01026579
     5D-05,1.62127290D-04,8.25375465D-04,6.87490710D-06,3.20940488D-06,9
     6.99996850D-01,2.97947487D-03,7.15781832D-05,-1.17751992D-05,-6.862
     770947D-04,-4.07167828D-06,2.83383774D-06,5.21702949D-04,1.19034158
     8D-06,1.39533548D-05,-1.24646384D-04,-3.06763188D-07,-1.64427990D-0
     97,6.64603820D-04,4.28272703D-03,1.05152837D-04,-1.47308723D-05,-9.
     $90230001D-04,-6.33469544D-06,3.61392343D-06,7.42181855D-04/
      DATA (SC(I),I=5221,5265)/1.64669650D-06,1.96212990D-05,-1.76330123
     1D-04,-4.30315481D-07,-2.30001923D-07,8.31561670D-04,6.13177993D-03
     2,1.52225980D-04,-1.64025836D-05,-1.41839496D-03,-9.45987426D-06,4.
     314352830D-06,1.05431024D-03,2.16924989D-06,2.74518440D-05,-2.48843
     4098D-04,-5.81225345D-07,-3.21046658D-07,1.07046940D-03,8.74953478D
     5-03,2.17923367D-04,-1.38083453D-05,-2.01919517D-03,-1.37964969D-05
     6,3.79185869D-06,1.49534011D-03,2.83210605D-06,3.82455426D-05,-3.50
     7069642D-04,-8.04261601D-07,-4.61777725D-07,1.41011760D-03,1.244819
     875D-02,3.09225061D-04,-1.23980530D-06,-2.85931937D-03,-1.97370851D
     9-05,1.34487769D-06,2.11822589D-03,3.53150325D-06,5.30561513D-05,-4
     $.91529919D-04,-1.06757626D-06,-6.36678484D-07,1.89185200D-03/
      DATA (SC(I),I=5266,5310)/1.76643043D-02,4.35583649D-04,3.12298089D
     1-05,-4.03058497D-03,-2.77782625D-05,-5.24600803D-06,2.99580918D-03
     2,4.65119384D-06,7.33024367D-05,-6.88498340D-04,-1.42448192D-06,-8.
     391852071D-07,2.57505210D-03,2.50094689D-02,6.09800791D-04,9.806205
     470D-05,-5.65945640D-03,-3.86307571D-05,-1.89555476D-05,4.23063415D
     5-03,6.68518544D-06,1.00914706D-04,-9.61916413D-04,-1.92116739D-06,
     6-1.18874593D-06,3.54475150D-03,3.53416999D-02,8.49068690D-04,2.179
     748378D-04,-7.92121291D-03,-5.31618555D-05,-4.34053649D-05,5.964643
     823D-03,1.08868822D-05,1.38353193D-04,-1.34043412D-03,-2.64617610D-
     906,-1.50945977D-06,4.92212890D-03,4.98642395D-02,1.17629884D-03,4.
     $12342615D-04,-1.10587630D-02,-7.24768341D-05,-8.25578527D-05/
      DATA (SC(I),I=5311,5355)/8.39521975D-03,1.89538409D-05,1.88876954D
     1-04,-1.86301763D-03,-3.69747448D-06,-1.80437894D-06,6.87913240D-03
     2,7.02598918D-02,1.62183387D-03,7.05236062D-04,-1.54071305D-02,-9.7
     39181624D-05,-1.40509533D-04,1.17961233D-02,3.27137757D-05,2.566580
     479D-04,-2.58224303D-03,-5.19284489D-06,-2.02596584D-06,9.65850560D
     5-03,9.88713407D-02,2.22546130D-03,1.12518422D-03,-2.14246026D-02,-
     61.31079448D-04,-2.21783372D-04,1.65450031D-02,5.39294729D-05,3.469
     769352D-04,-3.56889318D-03,-7.21611378D-06,-2.14571826D-06,1.360072
     830D-02,1.38943228D-01,3.03863829D-03,1.70905972D-03,-2.97324903D-0
     92,-1.73765939D-04,-3.31823757D-04,2.31593423D-02,8.43111936D-05,4.
     $66207642D-04,-4.91642830D-03,-9.85059007D-06,-2.13082323D-06/
      DATA (SC(I),I=5356,5400)/1.91792970D-02,1.94945299D-01,4.12649930D
     1-03,2.50604446D-03,-4.11656203D-02,-2.27750133D-04,-4.77286053D-04
     2,3.23418630D-02,1.25677815D-04,6.21653362D-04,-6.74702658D-03,-1.3
     30661844D-05,-1.94449968D-06,2.70455760D-02,2.72996073D-01,5.569048
     414D-03,3.58042363D-03,-5.68329979D-02,-2.94412539D-04,-6.65829772D
     5-04,4.50349297D-02,1.80134295D-04,8.20895475D-04,-9.21474219D-03,-
     61.68055618D-05,-1.51495683D-06,3.80828520D-02,3.81403462D-01,7.459
     771486D-03,5.01208846D-03,-7.81861949D-02,-3.73908803D-04,-9.046081
     825D-04,6.24835856D-02,2.49736898D-04,1.06977125D-03,-1.25078588D-0
     92,-2.07242473D-05,-7.03366303D-07,5.34668120D-02,5.31327717D-01,9.
     $89781601D-03,6.89267206D-03,-1.07084654D-01,-4.63156021D-04/
      DATA (SC(I),I=5401,5445)/-1.19697992D-03,8.62981025D-02,3.35312702
     1D-04,1.36832990D-03,-1.68411376D-02,-2.39664694D-05,7.70473960D-07
     2,7.47238050D-02,7.37540929D-01,1.29687896D-02,9.31383879D-03,-1.45
     3832238D-01,-5.52558419D-04,-1.53582796D-03,1.18494838D-01,4.351525
     480D-04,1.70264367D-03,-2.24295138D-02,-2.48397364D-05,3.33453295D-
     506,1.03768600D-01,1.01920062D+00,1.67005043D-02,1.23397854D-02,-1.
     697136478D-01,-6.19456797D-04,-1.89087770D-03,1.61482976D-01,5.4095
     76914D-04,2.02907108D-03,-2.94286278D-02,-1.97794409D-05,7.83545526
     8D-06,1.42887070D-01,1.40043510D+00,2.09769596D-02,1.59537790D-02,-
     92.63892351D-01,-6.17041578D-04,-2.18720765D-03,2.17915256D-01,6.32
     $833132D-04,2.24738421D-03,-3.78060561D-02,-2.50728179D-06/
      DATA (SC(I),I=5446,5490)/1.56588771D-05,1.94604680D-01,1.91033383D
     1+00,2.53828080D-02,1.99626638D-02,-3.48621518D-01,-4.57642134D-04,
     2-2.27199512D-03,2.90282961D-01,6.70711102D-04,2.15846413D-03,-4.71
     3080294D-02,3.74558836D-05,2.90922430D-05,2.61348840D-01,2.58159936
     4D+00,2.89562696D-02,2.38492213D-02,-4.52293173D-01,6.27653568D-06,
     5-1.87587692D-03,3.80039286D-01,5.85669360D-04,1.41499754D-03,-5.60
     6657986D-02,1.14209720D-04,5.12014882D-05,3.44780780D-01,3.44665001
     7D+00,2.98843043D-02,2.65967071D-02,-5.72166283D-01,9.78995944D-04,
     8-6.04668901D-04,4.85963312D-01,2.81838813D-04,-4.86962928D-04,-6.2
     90507163D-02,2.37498252D-04,8.34502441D-05,4.44676930D-01,4.5295673
     $5D+00,2.53833059D-02,2.66271961D-02,-6.98433998D-01/
      DATA (SC(I),I=5491,5535)/2.62241730D-03,1.92129057D-03,6.01525462D
     1-01,-3.21791031D-04,-4.01403543D-03,-6.06278904D-02,3.83748072D-04
     2,1.17014109D-04,5.57389400D-01,5.83283178D+00,1.24574027D-02,2.222
     313875D-02,-8.10536647D-01,4.73912693D-03,5.57247243D-03,7.11750573
     4D-01,-1.16971212D-03,-8.91186778D-03,-4.61834265D-02,4.41800299D-0
     54,1.15792339D-04,6.74448860D-01,7.32151586D+00,-9.59818924D-03,1.2
     67923041D-02,-8.77308199D-01,6.33867271D-03,8.93655077D-03,7.926606
     730D-01,-1.93090667D-03,-1.31437242D-02,-1.55819197D-02,2.22498942D
     8-04,1.96813071D-05,7.82959750D-01,8.91599987D+00,-3.60176333D-02,3
     9.13086454D-04,-8.68824803D-01,5.93542025D-03,9.55182890D-03,8.1982
     $4735D-01,-2.13022003D-03,-1.32757198D-02,2.51777850D-02/
      DATA (SC(I),I=5536,5580)/-2.79532005D-04,-1.64274472D-04,8.6993583
     10D-01,1.05084455D+01,-5.73742481D-02,-1.11283161D-02,-7.79216678D-
     201,3.15332413D-03,6.41640197D-03,7.86263643D-01,-1.59730345D-03,-8
     3.08089504D-03,6.00908924D-02,-6.63168477D-04,-2.84073109D-04,9.292
     439930D-01,1.20011961D+01,-6.62981966D-02,-1.79746405D-02,-6.364246
     557D-01,-4.25308114D-04,1.66410773D-03,7.10830520D-01,-6.68663639D-
     604,-8.43053395D-04,7.59832553D-02,-6.09901066D-04,-2.32173468D-04,
     79.64134180D-01,1.33396848D+01,-6.27959963D-02,-1.94592571D-02,-4.8
     82087626D-01,-2.91108341D-03,-1.90564515D-03,6.23210128D-01,1.29864
     9869D-04,4.34525366D-03,7.33025654D-02,-3.04913071D-04,-9.59000445D
     $-05,9.82571290D-01,1.45165921D+01,-5.21204642D-02,-1.72866454D-02/
      DATA (SC(I),I=5581,5625)/-3.45915331D-01,-3.77593686D-03,-3.421116
     132D-03,5.44522263D-01,5.42179569D-04,6.33027845D-03,6.07080578D-02
     2,-4.19115509D-05,1.02979421D-05,9.91706810D-01,1.55538771D+01,-3.9
     36559328D-02,-1.36651449D-02,-2.39168540D-01,-3.54336945D-03,-3.490
     404519D-03,4.82744557D-01,6.32936979D-04,6.13425291D-03,4.58951564D
     5-02,8.95687148D-05,5.83285996D-05,9.96088040D-01,1.64831199D+01,-2
     6.85014436D-02,-1.00489712D-02,-1.61233385D-01,-2.86175001D-03,-2.9
     71843243D-03,4.37767234D-01,5.59793353D-04,5.02023633D-03,3.2788284
     87D-02,1.25743066D-04,6.71693397D-05,9.98159260D-01,1.73341263D+01,
     9-1.97262357D-02,-7.05603197D-03,-1.06805256D-01,-2.12626266D-03,-2
     $.20724060D-03,4.06461023D-01,4.36033953D-04,3.75497158D-03/
      DATA (SC(I),I=5626,5670)/2.25874983D-02,1.16300333D-04,5.85309370D
     1-05,9.99133490D-01,1.81307891D+01,-1.33088774D-02,-4.80576179D-03,
     2-6.98774861D-02,-1.50193780D-03,-1.57503805D-03,3.85282151D-01,3.1
     36576032D-04,2.66238668D-03,1.51866248D-02,9.21750456D-05,4.5156112
     47D-05,9.99591430D-01,1.88907193D+01,-8.82184627D-03,-3.20595971D-0
     53,-4.53089107D-02,-1.02713820D-03,-1.08372553D-03,3.71224005D-01,2
     6.20206454D-04,1.82464448D-03,1.00410959D-02,6.74808135D-05,3.25878
     7262D-05,9.99806930D-01,1.96262768D+01,-5.77474324D-03,-2.10805276D
     8-03,-2.91859559D-02,-6.87156931D-04,-7.27943561D-04,3.62015424D-01
     9,1.48658579D-04,1.22245854D-03,6.55948033D-03,4.73039338D-05,2.261
     $80639D-05,9.99908600D-01,2.03458698D+01,-3.74606792D-03/
      DATA (SC(I),I=5671,5715)/-1.37172305D-03,-1.87090487D-02,-4.526166
     198D-04,-4.80917319D-04,3.56037551D-01,9.90150778D-05,8.06216783D-0
     24,4.24892613D-03,3.21147732D-05,1.52333457D-05,9.99956540D-01,2.10
     3551032D+01,-2.41400769D-03,-8.85962087D-04,-1.19492742D-02,-2.9487
     41399D-04,-3.14052210D-04,3.52185776D-01,6.47871491D-05,5.25843444D
     5-04,2.73460225D-03,2.14295499D-05,1.00949806D-05,9.99979290D-01,2.
     617576601D+01,-1.54778987D-03,-5.69046205D-04,-7.61015653D-03,-1.90
     7652050D-04,-2.03470708D-04,3.49714921D-01,4.20802121D-05,3.4037437
     84D-04,1.75297895D-03,1.39542095D-05,6.63093466D-06,9.99990080D-01,
     92.24559356D+01,-9.88627135D-04,-3.63989659D-04,-4.83608691D-03,-1.
     $22707107D-04,-1.30852991D-04,3.48137472D-01,2.69515417D-05/
      DATA (SC(I),I=5716,5760)/2.18788362D-04,1.11922170D-03,9.05565946D
     1-06,4.33166788D-06,9.99995380D-01,2.31514754D+01,-6.29726722D-04,-
     22.31965254D-04,-3.06775176D-03,-7.87952472D-05,-8.38514977D-05,3.4
     37130884D-01,1.76418563D-05,1.40112051D-04,7.12680310D-04,5.8139380
     47D-06,2.75466424D-06,9.99997680D-01,1.86811009D-03,4.94560682D-05,
     5-7.15935725D-06,-4.44483257D-04,-3.27685189D-06,1.78200424D-06,3.2
     64966162D-04,7.55916918D-07,9.17646071D-06,-7.95697736D-05,-1.95005
     7273D-07,-1.20128142D-07,3.32100120D-04,2.68224302D-03,7.15982891D-
     805,-8.89510914D-06,-6.38490610D-04,-4.81901931D-06,2.22183979D-06,
     94.63522550D-04,1.01032918D-06,1.29657602D-05,-1.12690499D-04,-2.86
     $910198D-07,-1.69040097D-07,4.33088970D-04,3.84052606D-03/
      DATA (SC(I),I=5761,5805)/1.02778224D-04,-9.75618832D-06,-9.1249735
     11D-04,-6.99583255D-06,2.50286693D-06,6.60382318D-04,1.32683200D-06
     2,1.82141748D-05,-1.59512733D-04,-3.96743291D-07,-2.35713034D-07,5.
     376735290D-04,5.48552752D-03,1.46504459D-04,-7.82915363D-06,-1.2983
     46056D-03,-1.00531337D-05,2.18733295D-06,9.39790134D-04,1.70297062D
     5-06,2.55120600D-05,-2.25259430D-04,-5.59139051D-07,-3.37055212D-07
     6,7.80951230D-04,7.81792691D-03,2.07594704D-04,5.90282738D-07,-1.84
     7042605D-03,-1.42485705D-05,4.85210337D-07,1.33607417D-03,2.1613068
     81D-06,3.55781849D-05,-3.17970738D-04,-7.27862291D-07,-4.73661846D-
     907,1.07158950D-03,1.11197757D-02,2.92706330D-04,2.19513210D-05,-2.
     $59976282D-03,-2.00013468D-05,-4.03247994D-06,1.89694016D-03/
      DATA (SC(I),I=5806,5850)/2.92257803D-06,4.95334408D-05,-4.47498520
     1D-04,-1.00327104D-06,-6.71592981D-07,1.48583820D-03,1.57887278D-02
     2,4.11001516D-04,6.57429538D-05,-3.66123719D-03,-2.78969494D-05,-1.
     333635556D-05,2.69036989D-03,4.21587279D-06,6.87617461D-05,-6.28579
     4320D-04,-1.38758606D-06,-8.85351193D-07,2.07703570D-03,2.23856281D
     5-02,5.74835015D-04,1.44533397D-04,-5.14393237D-03,-3.85834005D-05,
     6-3.00096156D-05,3.81019887D-03,7.07262079D-06,9.50717525D-05,-8.81
     7554743D-04,-1.92035133D-06,-1.14993695D-06,2.92147200D-03,3.170193
     871D-02,8.00995671D-04,2.72887776D-04,-7.21390345D-03,-5.30075765D-
     905,-5.68969870D-05,5.38868473D-03,1.25464633D-05,1.31088904D-04,-1
     $.23338252D-03,-2.72619651D-06,-1.41560323D-06,4.12789760D-03/
      DATA (SC(I),I=5851,5895)/4.48520138D-02,1.11220624D-03,4.67612966D
     1-04,-1.01024524D-02,-7.23814316D-05,-9.71135637D-05,7.61043101D-03
     2,2.19291658D-05,1.80121662D-04,-1.72191612D-03,-3.88527687D-06,-1.
     365985095D-06,5.85066620D-03,6.33984073D-02,1.53887612D-03,7.491363
     471D-04,-1.41295813D-02,-9.82075297D-05,-1.54264479D-04,1.07323821D
     5-02,3.65046577D-05,2.46548220D-04,-2.39838942D-03,-5.50496667D-06,
     6-1.86295457D-06,8.30761710D-03,8.95224022D-02,2.12129955D-03,1.144
     739752D-03,-1.97349280D-02,-1.32318348D-04,-2.32838445D-04,1.511028
     862D-02,5.76596300D-05,3.35875209D-04,-3.33245749D-03,-7.64675136D-
     906,-2.04073640D-06,1.18040100D-02,1.26255610D-01,2.91232229D-03,1.
     $68997317D-03,-2.75175219D-02,-1.76902420D-04,-3.38785231D-04/
      DATA (SC(I),I=5896,5940)/2.12328840D-02,8.69307367D-05,4.55147534D
     1-04,-4.61623924D-03,-1.04282013D-05,-2.17634697D-06,1.67638130D-02
     2,1.77790319D-01,3.98000725D-03,2.43513416D-03,-3.82877110D-02,-2.3
     34384650D-04,-4.79459694D-04,2.97660997D-02,1.26270389D-04,6.125374
     428D-04,-6.37119521D-03,-1.38889575D-05,-2.24760954D-06,2.37693260D
     5-02,2.49888090D-01,5.40961894D-03,3.44402397D-03,-5.31301710D-02,-
     63.07128750D-04,-6.63456361D-04,4.16066493D-02,1.78029674D-04,8.170
     774263D-04,-8.75238697D-03,-1.80341070D-05,-2.20137593D-06,3.360918
     870D-02,3.50404422D-01,7.30360679D-03,4.79638414D-03,-7.34767995D-0
     92,-3.96606978D-04,-8.99308003D-04,5.79455497D-02,2.44475646D-04,1.
     $07691358D-03,-1.19522895D-02,-2.25926076D-05,-1.91102318D-06/
      DATA (SC(I),I=5941,5985)/4.73326330D-02,4.89938053D-01,9.77649712D
     1-03,6.58520488D-03,-1.01179915D-01,-5.01822976D-04,-1.19280596D-03
     2,8.03322957D-02,3.27240745D-04,1.39597675D-03,-1.61953600D-02,-2.6
     39430082D-05,-1.16136015D-06,6.63038300D-02,6.82591486D-01,1.293906
     439D-02,8.90767015D-03,-1.38566291D-01,-6.16233546D-04,-1.54123754D
     5-03,1.10728123D-01,4.25671657D-04,1.76659006D-03,-2.17197534D-02,-
     62.95643246D-05,4.63408048D-07,9.22428320D-02,9.46780222D-01,1.6861
     78659D-02,1.18435998D-02,-1.88428458D-01,-7.21946058D-04,-1.9229716
     80D-03,1.51514155D-01,5.33913984D-04,2.15621192D-03,-2.87261506D-02
     9,-2.75243772D-05,3.76903773D-06,1.27227770D-01,1.30593180D+00,2.15
     $010913D-02,1.54119947D-02,-2.53874224D-01,-7.79687848D-04/
      DATA (SC(I),I=5986,6030)/-2.27867402D-03,2.05395949D-01,6.36734441
     1D-04,2.48301350D-03,-3.72749712D-02,-1.52337634D-05,1.01182078D-05
     2,1.73614190D-01,1.78874812D+00,2.65619085D-02,1.94911710D-02,-3.37
     3888283D-01,-7.12370264D-04,-2.48217334D-03,2.75100501D-01,7.014917
     426D-04,2.57780373D-03,-4.70867933D-02,1.68386492D-05,2.19356980D-0
     55,2.33801070D-01,2.42841535D+00,3.12727141D-02,2.36903139D-02,-4.4
     62368291D-01,-3.84285646D-04,-2.30172433D-03,3.62683861D-01,6.69710
     7439D-04,2.13300186D-03,-5.72013144D-02,8.25778835D-05,4.26900784D-
     805,3.09741430D-01,3.25972782D+00,3.40728749D-02,2.71760837D-02,-5.
     966297405D-01,4.10135629D-04,-1.37240299D-03,4.68191742D-01,4.52764
     $737D-04,6.67158920D-04,-6.54688415D-02,1.96243299D-04/
      DATA (SC(I),I=6031,6075)/7.56993770D-05,4.02077580D-01,4.31262322D
     1+00,3.23538735D-02,2.85363549D-02,-7.02725931D-01,1.89639068D-03,7
     2.42494994D-04,5.87377817D-01,-4.76466100D-05,-2.38616030D-03,-6.79
     3903741D-02,3.53104823D-04,1.18080026D-04,5.08840760D-01,5.60062177
     4D+00,2.27565204D-02,2.59492574D-02,-8.34818596D-01,4.09179139D-03,
     54.22040248D-03,7.08530962D-01,-8.52325998D-04,-7.21119282D-03,-5.9
     61240705D-02,4.81494104D-04,1.45021404D-04,6.23959830D-01,7.1047488
     77D+00,2.97456577D-03,1.81044654D-02,-9.33501140D-01,6.34034026D-03
     8,8.23955007D-03,8.10134939D-01,-1.74931495D-03,-1.25707618D-02,-3.
     936877725D-02,4.01734500D-04,9.60244271D-05,7.36624380D-01,8.760204
     $21D+00,-2.47803344D-02,5.80264431D-03,-9.63641396D-01/
      DATA (SC(I),I=6076,6120)/7.12640405D-03,1.05145585D-02,8.64790292D
     1-01,-2.26749063D-03,-1.51841383D-02,7.02673814D-03,-3.03626288D-05
     2,-7.43644047D-05,8.33550860D-01,1.04613364D+01,-5.20437478D-02,-7.
     342012355D-03,-9.04546154D-01,5.23635997D-03,8.89040925D-03,8.54684
     4048D-01,-2.03402270D-03,-1.20792751D-02,4.99450923D-02,-5.72623471
     5D-04,-2.67671537D-04,9.05015820D-01,1.20938939D+01,-6.87782714D-02
     6,-1.71958829D-02,-7.70497313D-01,1.45952385D-03,4.16901932D-03,7.8
     78036592D-01,-1.17034462D-03,-4.65524853D-03,7.74702869D-02,-7.4460
     87385D-04,-3.03515666D-04,9.50122360D-01,1.35765169D+01,-7.10414255
     9D-02,-2.12344500D-02,-6.03357797D-01,-1.99932653D-03,-5.26688233D-
     $04,6.94180038D-01,-1.98726698D-04,2.39209449D-03,8.30408645D-02/
      DATA (SC(I),I=6121,6165)/-4.99772889D-04,-1.81529249D-04,9.7520888
     10D-01,1.48801828D+01,-6.24874312D-02,-2.03380995D-02,-4.43361573D-
     201,-3.77935851D-03,-3.18290947D-03,6.01587038D-01,4.39911939D-04,6
     3.16189976D-03,7.32029162D-02,-1.68233245D-04,-4.04806096D-05,9.880
     444580D-01,1.60174729D+01,-4.94104676D-02,-1.68497120D-02,-3.116328
     547D-01,-4.02728625D-03,-3.88230837D-03,5.24997414D-01,6.77207906D-
     604,6.91506383D-03,5.75080412D-02,4.24417682D-05,4.23082183D-05,9.9
     74315700D-01,1.70202203D+01,-3.64313970D-02,-1.27691235D-02,-2.1249
     88778D-01,-3.46777036D-03,-3.50585090D-03,4.67513440D-01,6.60796200
     9D-04,6.06400679D-03,4.21022008D-02,1.24809842D-04,7.01981146D-05,9
     $.97312080D-01,1.79228344D+01,-2.56523162D-02,-9.14511428D-03/
      DATA (SC(I),I=6166,6210)/-1.41905490D-01,-2.67388144D-03,-2.764314
     143D-03,4.26744002D-01,5.40849492D-04,4.71507401D-03,2.94763642D-02
     2,1.33527151D-04,6.84093533D-05,9.98730480D-01,1.87546514D+01,-1.75
     3134347D-02,-6.31247973D-03,-9.33839919D-02,-1.93291914D-03,-2.0227
     49448D-03,3.98821493D-01,4.04392026D-04,3.42380753D-03,2.00371389D-
     502,1.12872224D-04,5.56724249D-05,9.99399920D-01,1.95380399D+01,-1.
     617063746D-02,-4.25056363D-03,-6.08110906D-02,-1.34177474D-03,-1.41
     7456731D-03,3.80131167D-01,2.86327878D-04,2.38325256D-03,1.33510592
     8D-02,8.55881655D-05,4.14393861D-05,9.99715910D-01,2.02890259D+01,-
     97.70927011D-03,-2.81338992D-03,-3.92966712D-02,-9.07079725D-04,-9.
     $60749547D-04,3.67812158D-01,1.96387712D-04,1.61385189D-03/
      DATA (SC(I),I=6211,6255)/8.77243789D-03,6.10624216D-05,2.92575318D
     1-05,9.99865180D-01,2.10186617D+01,-5.02313205D-03,-1.83960861D-03,
     2-2.52506752D-02,-6.02136138D-04,-6.39594312D-04,3.59783079D-01,1.3
     31848895D-04,1.07228617D-03,5.70462964D-03,4.21740718D-05,1.9977768
     43D-05,9.99935970D-01,2.17343842D+01,-3.24774497D-03,-1.19246505D-0
     53,-1.61572918D-02,-3.94311889D-04,-4.19948138D-04,3.54592471D-01,8
     6.68276096D-05,7.03100906D-04,3.68297323D-03,2.84053541D-05,1.33549
     7302D-05,9.99969550D-01,2.24411110D+01,-2.08772627D-03,-7.68041407D
     8-04,-1.03051670D-02,-2.55685514D-04,-2.73198757D-04,3.51255686D-01
     9,5.62287584D-05,4.56917790D-04,2.36558120D-03,1.87337600D-05,8.819
     $14323D-06,9.99985330D-01,2.31420544D+01,-1.33591959D-03/
      DATA (SC(I),I=6256,6300)/-4.92246543D-04,-6.55544886D-03,-1.649415
     160D-04,-1.76429791D-04,3.49119261D-01,3.62112029D-05,2.94888892D-0
     24,1.51463882D-03,1.20222368D-05,5.79683730D-06,9.99993000D-01,2.38
     3392950D+01,-8.52189693D-04,-3.14101350D-04,-4.16327685D-03,-1.0590
     45378D-04,-1.13033888D-04,3.47755692D-01,2.38761059D-05,1.88841005D
     5-04,9.63081001D-04,8.03379969D-06,3.66521699D-06,9.99996580D-01,2.
     645341757D+01,-5.42382136D-04,-2.00304740D-04,-2.64008466D-03,-6.75
     7654772D-05,-7.24249301D-05,3.46890464D-01,1.46030613D-05,1.2096655
     82D-04,6.14380958D-04,5.02380830D-06,2.44712551D-06,9.99998530D-01,
     91.15611582D-03,3.27031930D-05,-4.30464652D-06,-2.81474278D-04,-2.3
     $6747200D-06,1.07270649D-06,2.00523308D-04,4.86398891D-07/
      DATA (SC(I),I=6301,6345)/5.95351509D-06,-4.98813081D-05,-1.4643088
     17D-07,-8.65490052D-08,1.73691800D-04,1.66004111D-03,4.70584906D-05
     2,-5.32485277D-06,-4.03559869D-04,-3.44246456D-06,1.34841658D-06,2.
     386933060D-04,6.07024766D-07,8.40178258D-06,-7.10249538D-05,-1.9414
     49246D-07,-1.10367140D-07,2.33708230D-04,2.37896392D-03,6.72731795D
     5-05,-5.74017204D-06,-5.76683732D-04,-4.90629139D-06,1.51314936D-06
     6,4.09934958D-04,8.17754496D-07,1.18129062D-05,-1.00960261D-04,-2.6
     70452763D-07,-1.66944267D-07,3.19242000D-04,3.40303781D-03,9.573979
     807D-05,-4.39327450D-06,-8.21337908D-04,-6.93865898D-06,1.24854619D
     9-06,5.85169530D-04,1.03193514D-06,1.66537050D-05,-1.43197673D-04,-
     $3.51110334D-07,-2.37676432D-07,4.41363510D-04,4.85961081D-03/
      DATA (SC(I),I=6346,6390)/1.35780961D-04,1.14388120D-06,-1.16621984
     1D-03,-9.78898117D-06,6.83881232D-08,8.34541088D-04,1.32643277D-06,
     22.33874647D-05,-2.02640323D-04,-4.99805452D-07,-3.36568877D-07,6.1
     36053030D-04,6.92869445D-03,1.91892966D-04,1.49881326D-05,-1.651365
     402D-03,-1.38022638D-05,-2.93070846D-06,1.18911795D-03,1.83041517D-
     506,3.27245408D-05,-2.86555624D-04,-6.92335172D-07,-4.77931800D-07,
     68.66339140D-04,9.86548449D-03,2.70291117D-04,4.32742146D-05,-2.333
     709645D-03,-1.92543535D-05,-9.10518358D-06,1.69305946D-03,2.6701416
     80D-06,4.56736102D-05,-4.04949154D-04,-9.13204306D-07,-6.42573573D-
     907,1.22534710D-03,1.40313306D-02,3.79690360D-04,9.42676501D-05,-3.
     $28992160D-03,-2.67390631D-05,-2.02561314D-05,2.40715131D-03/
      DATA (SC(I),I=6391,6435)/4.55934432D-06,6.37256327D-05,-5.70414573
     1D-04,-1.33640040D-06,-8.50176541D-07,1.74061340D-03,1.99388660D-02
     2,5.32018064D-04,1.77689905D-04,-4.63286414D-03,-3.70755916D-05,-3.
     383008836D-05,3.41873343D-03,8.18593231D-06,8.86020712D-05,-8.02643
     4601D-04,-1.92567976D-06,-1.05600753D-06,2.48014120D-03,2.83141320D
     5-02,7.43473167D-04,3.04981047D-04,-6.51800939D-03,-5.11396534D-05,
     6-6.55183550D-05,4.84975951D-03,1.44231728D-05,1.22853032D-04,-1.12
     7742746D-03,-2.78895709D-06,-1.26138653D-06,3.54082040D-03,4.018118
     865D-02,1.03610091D-03,4.90310047D-04,-9.16324368D-03,-7.01371308D-
     905,-1.04561844D-04,6.87133679D-03,2.42362930D-05,1.69774708D-04,-1
     $.58109509D-03,-3.97028268D-06,-1.47811243D-06,5.06000990D-03/
      DATA (SC(I),I=6436,6480)/5.69788946D-02,1.43979955D-03,7.52570356D
     1-04,-1.28702089D-02,-9.57251254D-05,-1.58988718D-04,9.72209260D-03
     2,3.86040291D-05,2.33923937D-04,-2.21229203D-03,-5.63369381D-06,-1.
     371190835D-06,7.23125120D-03,8.07215567D-02,1.99469327D-03,1.117775
     453D-03,-1.80551184D-02,-1.29941733D-04,-2.33412416D-04,1.37336108D
     5-02,5.86660902D-05,3.20969785D-04,-3.08840507D-03,-7.82158522D-06,
     6-1.94111626D-06,1.03252260D-02,1.14217151D-01,2.75376830D-03,1.621
     775218D-03,-2.52886998D-02,-1.75229603D-04,-3.33922287D-04,1.936211
     835D-02,8.61049704D-05,4.38105238D-04,-4.29906951D-03,-1.06612976D-
     905,-2.21993614D-06,1.47171060D-02,1.61361137D-01,3.78614319D-03,2.
     $31227516D-03,-3.53468897D-02,-2.34490370D-04,-4.68292448D-04/
      DATA (SC(I),I=6481,6525)/2.72310151D-02,1.22900607D-04,5.94269653D
     1-04,-5.96261262D-03,-1.42404759D-05,-2.50867377D-06,2.09212360D-02
     2,2.27524268D-01,5.17984657D-03,3.25154747D-03,-4.92748691D-02,-3.1
     30801125D-04,-6.45528664D-04,3.81833582D-02,1.71426878D-04,7.994337
     427D-04,-8.23182493D-03,-1.86245137D-05,-2.78171386D-06,2.96334330D
     5-02,3.20053592D-01,7.04289436D-03,4.51730631D-03,-6.84616270D-02,-
     64.06800252D-04,-8.75092615D-04,5.33429306D-02,2.34318772D-04,1.063
     761406D-03,-1.12987558D-02,-2.36363371D-05,-2.95699868D-06,4.177967
     850D-02,4.48899586D-01,9.50050063D-03,6.20173130D-03,-9.47185321D-0
     92,-5.23467741D-04,-1.16470131D-03,7.41820570D-02,3.13506024D-04,1.
     $39399221D-03,-1.53913638D-02,-2.88977462D-05,-2.84266263D-06/
      DATA (SC(I),I=6526,6570)/5.85670310D-02,6.27365265D-01,1.26831316D
     1-02,8.40505372D-03,-1.30347564D-01,-6.57177324D-04,-1.51557448D-03
     2,1.02581580D-01,4.09227077D-04,1.78863875D-03,-2.07632239D-02,-3.3
     30822109D-05,-2.03217189D-06,8.15274350D-02,8.72932164D-01,1.669701
     409D-02,1.12194747D-02,-1.78162562D-01,-7.94725659D-04,-1.91384595D
     5-03,1.40858332D-01,5.18301494D-04,2.22524054D-03,-2.76516443D-02,-
     63.37621435D-05,1.02359158D-07,1.12535990D-01,1.20804801D+00,2.1562
     76545D-02,1.46939936D-02,-2.41396998D-01,-9.04535940D-04,-2.3150041
     80D-03,1.91718981D-01,6.29104996D-04,2.64040311D-03,-3.61952533D-02
     9,-2.61708361D-05,4.92548000D-06,1.53771160D-01,1.66061518D+00,2.70
     $988613D-02,1.87700131D-02,-3.23379574D-01,-9.21572680D-04/
      DATA (SC(I),I=6571,6615)/-2.61857650D-03,2.58042958D-01,7.15934566
     1D-04,2.89580369D-03,-4.62705281D-02,-2.02437788D-06,1.47513637D-05
     2,2.07562570D-01,2.26368363D+00,3.27237824D-02,2.31719831D-02,-4.26
     3775310D-01,-7.26594543D-04,-2.63169754D-03,3.42355668D-01,7.309476
     449D-04,2.72911739D-03,-5.72046240D-02,5.16548086D-05,3.31072743D-0
     55,2.76043580D-01,3.05348822D+00,3.71575201D-02,2.72467827D-02,-5.5
     62085937D-01,-1.26303181D-04,-2.03206719D-03,4.45763183D-01,5.95851
     7629D-04,1.70462029D-03,-6.73199948D-02,1.51053960D-04,6.43296377D-
     805,3.60498330D-01,4.06448955D+00,3.80925726D-02,2.97919477D-02,-6.
     995043672D-01,1.13162188D-03,-3.77712182D-04,5.66043771D-01,2.08639
     $926D-04,-7.69567831D-04,-7.33453480D-02,3.03794597D-04/
      DATA (SC(I),I=6616,6660)/1.09784336D-04,4.60303750D-01,5.31977012D
     1+00,3.21562628D-02,2.90462210D-02,-8.42795130D-01,3.21711885D-03,2
     2.70220553D-03,6.94721601D-01,-5.02867157D-04,-5.16674191D-03,-7.00
     3464584D-02,4.73341688D-04,1.55827866D-04,5.71522220D-01,6.81603782
     4D+00,1.59800341D-02,2.32422712D-02,-9.70154091D-01,5.82342872D-03,
     56.92506844D-03,8.13866959D-01,-1.44571047D-03,-1.10094868D-02,-5.1
     62293592D-02,5.20436841D-04,1.53548537D-04,6.85720760D-01,8.5069811
     79D+00,-1.07821497D-02,1.20334856D-02,-1.04093891D+00,7.70148742D-0
     83,1.05631999D-02,8.96310096D-01,-2.23457749D-03,-1.57526970D-02,-1
     9.41776213D-02,2.34859257D-04,3.01847181D-05,7.90580580D-01,1.02976
     $816D+01,-4.20571485D-02,-2.11510949D-03,-1.02266375D+00/
      DATA (SC(I),I=6661,6705)/7.12956648D-03,1.09117541D-02,9.16122873D
     1-01,-2.37159436D-03,-1.55223018D-02,3.31800190D-02,-3.55268798D-04
     2,-1.95735649D-04,8.74136480D-01,1.20655794D+01,-6.68337700D-02,-1.
     346576452D-02,-9.11740964D-01,3.79147805D-03,7.10349297D-03,8.68099
     4601D-01,-1.71896112D-03,-9.25431975D-03,7.24642833D-02,-7.79956668
     5D-04,-3.38083098D-04,9.31079430D-01,1.37035241D+01,-7.69571177D-02
     6,-2.18594765D-02,-7.42060283D-01,-4.05782427D-04,1.66153252D-03,7.
     775154650D-01,-6.69094052D-04,-8.69027994D-04,8.95533521D-02,-7.036
     870417D-04,-2.76920056D-04,9.64755490D-01,1.51544113D+01,-7.2762464
     96D-02,-2.30785929D-02,-5.61220887D-01,-3.30371849D-03,-2.34657245D
     $-03,6.70776257D-01,2.11630873D-04,5.06368108D-03,8.56434991D-02/
      DATA (SC(I),I=6706,6750)/-3.50649814D-04,-1.17727747D-04,9.8270741
     10D-01,1.64138343D+01,-6.03757822D-02,-2.02957454D-02,-4.02512508D-
     201,-4.32469960D-03,-4.02077105D-03,5.78173484D-01,6.57763162D-04,7
     3.32300132D-03,7.06943531D-02,-4.91206181D-05,7.00762795D-06,9.9169
     44470D-01,1.75093343D+01,-4.59607879D-02,-1.59757190D-02,-2.7832330
     59D-01,-4.07536053D-03,-4.06629028D-03,5.05826906D-01,7.46858070D-0
     64,7.09199303D-03,5.33870775D-02,1.02334507D-04,6.44480161D-05,9.96
     7048510D-01,1.84784778D+01,-3.30598123D-02,-1.17277888D-02,-1.87686
     8680D-01,-3.30104111D-03,-3.39251457D-03,4.53261483D-01,6.55302062D
     9-04,5.80898254D-03,3.81381690D-02,1.44316202D-04,7.60609831D-05,9.
     $98126250D-01,1.93562686D+01,-2.29008112D-02,-8.22999553D-03/
      DATA (SC(I),I=6751,6795)/-1.24375185D-01,-2.45833550D-03,-2.564864
     158D-03,4.16703937D-01,5.08775526D-04,4.35001857D-03,2.62796233D-02
     2,1.34025333D-04,6.69502877D-05,9.99111890D-01,2.01706414D+01,-1.54
     3629699D-02,-5.60491682D-03,-8.14032506D-02,-1.73969473D-03,-1.8307
     47736D-03,3.91978466D-01,3.68888746D-04,3.08782273D-03,1.76770240D-
     502,1.06395195D-04,5.19495686D-05,9.99578690D-01,2.09421499D+01,-1.
     602569941D-02,-3.73940099D-03,-5.28015916D-02,-1.19151229D-03,-1.26
     7019807D-03,3.75563033D-01,2.57660751D-04,2.11815306D-03,1.16908598
     8D-02,7.82280420D-05,3.75184176D-05,9.99799790D-01,2.16852157D+01,-
     96.71806379D-03,-2.45966334D-03,-3.40213790D-02,-7.98620644D-04,-8.
     $47250153D-04,3.64812545D-01,1.73400906D-04,1.42077725D-03/
      DATA (SC(I),I=6796,6840)/7.64466104D-03,5.44677927D-05,2.62315686D
     1-05,9.99905000D-01,2.24096487D+01,-4.35998207D-03,-1.60099554D-03,
     2-2.18138454D-02,-5.26893862D-04,-5.59755382D-04,3.57832241D-01,1.1
     35400489D-04,9.37304463D-04,4.95016180D-03,3.74176394D-05,1.7746390
     46D-05,9.99954950D-01,2.31219860D+01,-2.81139999D-03,-1.03411379D-0
     53,-1.39389890D-02,-3.42636135D-04,-3.65437451D-04,3.53331758D-01,7
     6.61869049D-05,6.11277626D-04,3.18368179D-03,2.53636425D-05,1.16011
     7909D-05,9.99978260D-01,2.38265271D+01,-1.80323940D-03,-6.64652617D
     8-04,-8.87738078D-03,-2.21834466D-04,-2.37517379D-04,3.50445926D-01
     9,4.85584410D-05,3.96882964D-04,2.04922854D-03,1.57042929D-05,7.731
     $70805D-06,9.99989400D-01,2.45260661D+01,-1.15229560D-03/
      DATA (SC(I),I=6841,6864)/-4.24786621D-04,-5.64464289D-03,-1.427432
     109D-04,-1.52056951D-04,3.48600876D-01,3.25023056D-05,2.54060835D-0
     24,1.29879358D-03,1.12412835D-05,4.86834414D-06,9.99995070D-01,2.52
     3224119D+01,-7.34401571D-04,-2.71474769D-04,-3.58178869D-03,-9.0927
     44586D-05,-9.81419282D-05,3.47428588D-01,1.92460032D-05,1.63833189D
     5-04,8.35133112D-04,6.47337758D-06,3.32487001D-06,9.99997670D-01/
C
      IF(ZLTOMF.NE.ZBARM) THEN
        CONV2=ZBARM**ANV13
        CONV4=CONV2*ZBARM**2
        CONV1=ANVA*ABARX*ZBARM
        CONV2=ANVB/(CONV2*ZBARM)
        CONV3=ANVC*CONV4*ZBARM
        CONV4=ANVD*CONV4/ABARX
        CONV5=CONV2*CONV4*EV
        CONV6=CONV2*EV
        ZLTOMF=ZBARM
      END IF
C
      VF=CONV1/RHOX
      TF=CONV6*TEVX
C
C     compute Thomas-Fermi eos in single element scaled variables.
C     the atomic radius is VF/(PIKON*ZBARM*4.E24/3.)
C
C     check for out of range rho
C
      IF (VF.LT.VFMN) THEN
        VFS=VF
        VF=ANVE*VFMN
      ELSEIF (VF.GT.VFMX) THEN
        VFS=VF
        VF=VFMX
      ELSE
        VFS=ZERO
      END IF
      X=LOG(VF)
      JX=MAX(1,MIN(NX-1,INT(((X*CL10)-XLM)/DXL)+1))
      W=TF*VF**ANV23
      IF (W.LT.WMN) GO TO 180
      JY=1+((LOG(W)*CL10)-WLM)/DWL
      IS=NS(JX)+JY-1
      IF (IS.GE.NS(JX+1)) GO TO 260
      Y=LOG(ONE+CF*W)
      TFW=TF
      JSW=0
      GO TO 190
C
C     off bottom of t range
C
  180 JY=1
      IS=NS(JX)
      Y=YB(1)
      WS=W/WMN
      TFW=TF*WMN/W
      W=WMN
      JSW=1
C
C     in center of rho, t range, so
C     use stored table for interpolation
C
  190 Z1=TC(13,IS)
      JX2=JX+1
      IS3=IS+1
      IF (IS3.GE.NS(JX2)) GO TO 200
      Z3=TC(13,IS3)
      GO TO 210
  200 Z3=ONE
  210 IF (JX2.GE.NX) GO TO 230
      IS2=NS(JX2)+JY-1
      Z2=TC(13,IS2)
      IS4=IS2+1
      IF (IS4.GE.NS(JX2+1)) GO TO 220
      Z4=TC(13,IS4)
      GO TO 240
  220 Z4=ONE
      GO TO 240
  230 Z2=Z1
      Z4=Z3
  240 ZSCALE=((Z1*(XB(JX+1)-X)+Z2*(X-XB(JX)))*(YB(JY+1)-Y)
     &       +(Z3*(XB(JX+1)-X)+Z4*(X-XB(JX)))*(Y-YB(JY)))
     &      /((XB(JX+1)-XB(JX))*(YB(JY+1)-YB(JY)))
C
C     call interpolation routine
C
      CALL ANSMFT (X,Y,XB(JX),XB(JX+1),YB(JY),YB(JY+1),TC(1,IS)
     &    ,F,FX,FY,FXX,FXY,FYY)
C
      WA=CF*W
      WB=WA/(ONE+WA)
      WC=TFW/VF
      EF=TFW*WB*FY
      PF=ANV23*EF/VF+WC*FX
      SF=F+EF/TFW
      CVF=EF/TFW+WB*WB*(FY/WA+FYY)
      TPF=WC*(ANV23*CVF+FX+WB*FXY)
      VPF=ANV53*PF-ANV23*(TPF+WB*WC*FXY)-WC*FXX
C
C     off bottom of t range
C
      IF (JSW.NE.0) THEN
        WF=WS*WS
        VPF=WF*(VPF-ANV43*PF+ANV23*TPF)
        PF=PF*WF
        EF=EF*WF
        SF=SF*WS
        TPF=TWO*PF
        CVF=TWO*EF/TF
      END IF
      GO TO 270
C
C     off top of t range
C
  260 PF=TF/VF
      EF=THREEH*TF
      SF=THREEH*(ONE+LOG(CF*W))
      VPF=PF
      TPF=PF
      CVF=THREEH
      ZSCALE=ONE
C
C     correct for rho out of range
C
  270 IF (VFS.NE.ZERO) THEN
        WA=VF/VFS
        SF=SF-(VF*PF/TF)*LOG(WA)
        PF=WA*PF
        TPF=WA*TPF
        VPF=PF
      END IF
C
C     rescale for external units
C
      PE=CONV3*PF
      EE=CONV4*EF
      SE=CONV5*SF
      DPRE=CONV3*VPF/RHOX
      DPTE=CONV3*TPF/TEVX
      CVE=CONV5*CVF
      ZBAR=ZSCALE*ZBARM
      RETURN
      END
